--- **LibInit** should make using Ace3 even more easier and pleasant.
-- An embeddable library which offer clean methods to build a configuration table
-- instead of directly fiddling wit an Ace options table
-- @name LibInit
-- @class module
-- @author Alar of Daggerspine
-- @release 31
--
local __FILE__=tostring(debugstack(1,2,0):match("(.*):9:")) -- Always check line number in regexp and file

local MAJOR_VERSION = "LibInit"
local MINOR_VERSION = 33
local off=(_G.RED_FONT_COLOR_CODE or '|cffff0000') .. _G.VIDEO_OPTIONS_DISABLED ..  _G.FONT_COLOR_CODE_CLOSE or '|r'
local on=(_G.GREEN_FONT_COLOR_CODE or '|cff00ff00') .. _G.VIDEO_OPTIONS_ENABLED ..  _G.FONT_COLOR_CODE_CLOSE or '|r'
local nop=function()end
local pp=print -- Keeping a handy plain print around
local assert=assert
local strconcat=strconcat
local tostring=tostring
local _G=_G -- Unmodified env
local dprint=function() end
--@debug@
LoadAddOn("LibDebug")
LoadAddOn("Blizzard_DebugTools")
if LibDebug then
	--pulling libdebug print in without pulling also the whole _G management and without changing loading addon env
	LibDebug()
	dprint=print
	setfenv(1,_G)
end
--@end-debug@
--GAME_LOCALE="itIT"
local me, ns = ...
local LibStub=LibStub
local obj,old=LibStub:NewLibrary(MAJOR_VERSION,MINOR_VERSION)
local upgrading
if obj then
	upgrading=old
--@debug@
	if old then
		dprint(strconcat("Upgrading ",MAJOR_VERSION,'.',old,' to',MINOR_VERSION,' from ',__FILE__))
	else
		dprint(strconcat("Loading ",MAJOR_VERSION,'.',MINOR_VERSION,' from ',__FILE__))
	end
--@end-debug@
else
--@debug@
	dprint(strconcat("Equal or newer ",MAJOR_VERSION,' already loaded from ',__FILE__))
--@end-debug@
	return
end
local lib=obj --#Lib
local L
local C=LibStub("LibInit-Colorize")()
-- Upvalues
local _G=_G
local floor=floor
local abs=abs
local wipe=wipe
local print=print
local next = next
local pairs = pairs
local pcall = pcall
local type = type
local GetTime = GetTime
local gcinfo = gcinfo
local unpack = unpack
local geterrorhandler = geterrorhandler
local GetContainerNumSlots=GetContainerNumSlots
local GetContainerItemID=GetContainerItemID
local GetItemInfo=GetItemInfo
local UnitHealth=UnitHealth
local UnitHealthMax=UnitHealthMax
local setmetatable=setmetatable
local NUM_BAG_SLOTS=NUM_BAG_SLOTS
local InCombatLockdown=InCombatLockdown
local error=error
local tinsert=tinsert
local debugstack=debugstack
local ipairs=ipairs
local GetAddOnMetadata=GetAddOnMetadata
local format=format
local tostringall=tostringall
local tonumber=tonumber
local strconcat=strconcat
local strjoin=strjoin
local strsplit=strsplit
local select=select
local coroutine=coroutine
local cachedGetItemInfo
local toc=select(4,GetBuildInfo())

--]]
-- Help sections
local titles
local RELNOTES
local LIBRARIES
local PROFILE
local HELPSECTIONS
local AceConfig = LibStub("AceConfig-3.0",true)
assert(AceConfig,"LibInit needs AceConfig-3.0")
local AceRegistry = LibStub("AceConfigRegistry-3.0",true)
local AceDBOptions=LibStub("AceDBOptions-3.0",true)
local AceConfigDialog=LibStub("AceConfigDialog-3.0",true)
local AceGUI=LibStub("AceGUI-3.0",true)
local Ace=LibStub("AceAddon-3.0")
local AceLocale=LibStub("AceLocale-3.0",true)
local AceDB  = LibStub("AceDB-3.0",true)


-- Persistent tables
lib.mixinTargets=lib.mixinTargets or {}
lib.toggles=lib.toggles or {}
lib.chats=lib.chats or {}
lib.options=lib.options or {}
lib.pool=lib.pool or setmetatable({},{__mode="k"})
lib.coroutines=lib.coroutines or setmetatable({},{__index=function(t,k) rawset(t,k,{}) return t[k] end})
-- Recycling function from ACE3
local new, del, copy, cached, stats
do
	local pool = lib.pool
--@debug@
	local newcount, delcount,createdcount,cached = 0,0,0
--@end-debug@
	function new()
--@debug@
		newcount = newcount + 1
--@end-debug@
		local t = next(pool)
		if t then
			pool[t] = nil
			return t
		else
--@debug@
			createdcount = createdcount + 1
--@end-debug@
			return {}
		end
	end
	function copy(t)
		local c = new()
		for k, v in pairs(t) do
			c[k] = v
		end
		return c
	end
	function del(t)
--@debug@
		delcount = delcount + 1
--@end-debug@
		wipe(t)
		pool[t] = true
	end
	function cached()
		local n = 0
		for k in pairs(pool) do
			n = n + 1
		end
		return n
	end
--@debug@
	function stats()
		print("Created:",createdcount)
		print("Aquired:",newcount)
		print("Released:",delcount)
		print("Cached:",cached())
	end
--@end-debug@
--[===[@non-debug@
	function stats()
		return
	end
--@end-non-debug@]===]
end
--- Create a new AceAddon-3.0 addon.
-- Any library you specified will be embeded, and the addon will be scheduled for
-- its OnInitializee and OnEnabled callbacks.
-- The final addon object, with all libraries embeded, will be returned.
-- Options table format:
-- 	*profile: choose the initial profile (if omittete, uses a per character one)
--		*noswitch: disables Ace profile managemente, user will not be able to change it
--		*nogui: do not generate a gui for configuration
--		*nohelp: do not generate help (actually, help generation is not yet implemented)
--		*enhancedProfile: adds "Switch all profiles to default" and "Remove unused profiles" do Ace profile gui
--
-- @tparam[opt] table target to use as a base for the addon (optional)
-- @tparam string name Name of the addon object to create
-- @tparam[opt] table options options list
-- @tparam[opt] bool full If true, all available and embeddable Ace3 library are embedded
-- @tparam[opt] string ... List of libraries to embed into the addon
-- @treturn table new addon
--
-- @usage
-- --Create a simple addon object
-- MyAddon = LibStub("LibInit"):NewAddon("MyAddon", "AceEvent-3.0")
--
-- -- Create a Addon object based on the table of a frame
-- local MyFrame = CreateFrame("Frame")
-- MyAddon = LibStub("LibInit"):NewAddon(MyFrame, "MyAddon", "AceEvent-3.0")
-- -- Create an Addon based on the private table provided by Blizzard Code:
-- local myname,addon = ...
-- LibStub("LibInit"):NewAddon(addon,myname)
--
---
function lib:NewAddon(target,...)
	local name
	local customOptions
	local start=1
	if type(target) ~= "table" then
		name=target
		target={}
	else
		name=(select(1,...))
		start=2
	end
	assert(Ace,"Could not find Ace3 Library")
	assert(type(name)=="string","Name is mandatory")
	local appo={}
	appo[MAJOR_VERSION]=true
	appo["AceConsole-3.0"]=true
	for i=start,select('#',...) do
		local mix=select(i,...)
		if type(mix)=="boolean" and mix then
			for n,k in  LibStub:IterateLibraries() do
				if (n:match("Ace%w*-3%.0") and k.Embed) then appo[n]=true end
			end
		elseif type(mix)=="string" then
			appo[mix]=true
		elseif type(mix)=="table" then
			customOptions=mix
		end
	end
	local mixins=new()
	for i,_ in pairs(appo) do
		tinsert(mixins,i)
	end
	local target=Ace:NewAddon(target,name,unpack(mixins))
	del(mixins)
	appo=nil
	local options={}
	options.name=name
	options.first=true
	options.libstub=__FILE__
	options.version=GetAddOnMetadata(name,'Version') or "Internal"
	if (options.version:sub(1,1)=='@') then
		options.version=GetAddOnMetadata(name,'X-Version') or "Internal"
	end
	local b,e=options.version:find(" ")
	if b and b>1 then
		options.version=options.version:sub(1,b-1)
	end
	options.revision=GetAddOnMetadata(name,'X-revision') or "Alpha"
	if (options.revision:sub(1,1)=='@') then
		options.revision='Development'
	end
	options.prettyversion=format("%s (Revision: %s)",tostringall(options.version,options.revision))
	options.title=GetAddOnMetadata(name,"title") or 'No title'
	options.notes=GetAddOnMetadata(name,"notes") or 'No notes'
	-- Setting sensible default for mandatory fields
	options.ID=GetAddOnMetadata(name,"X-ID") or name
	options.DATABASE=GetAddOnMetadata(name,"X-Database") or "db" .. options.ID
	lib.toggles[target]={}
	if customOptions then
		for k,v in pairs(customOptions) do
			local key=strlower(k)
			if key=="enhanceprofile" then key = "enhancedprofile" end
			if 	key=="profile"
				or key=="noswitch"
				or key=="nogui"
				or key=="nohelp"
				or key=="enhancedprofile"
					then
				options[key]=v
			else
				error("Invalid options: " .. k)
			end
		end
	end
	lib.options[target]=options
	RELNOTES=L["Release Notes"]
	PROFILE=L["Profile"]
	HELPSECTIONS={PROFILE,RELNOTES}
	titles={
		RELNOTES=RELNOTES,
		PROFILE=PROFILE
	}
	return target
end
-- Combat scheduler done with LibCallbackHandler
local CallbackHandler = LibStub:GetLibrary("CallbackHandler-1.0")
if not lib.CombatScheduler then
	lib.CombatScheduler = CallbackHandler:New(lib,"_OnLeaveCombat","_CancelCombatAction")
	lib.CombatFrame=CreateFrame("Frame")
	lib.CombatFrame:SetScript("OnEvent",function()
		lib.CombatScheduler:Fire("LIBINIT_END_COMBAT")
		if lib.CombatScheduler.insertQueue then
			wipe(lib.CombatScheduler.insertQueue) -- hackish, depends on internal callbackhanlder implementation
		end
		wipe(lib.CombatScheduler.events)
		lib.CombatScheduler.recurse=0
		for _,co in pairs(lib.coroutines) do
			if co.waiting then
				co.waiting=false
				co.repeater()
			end
		end
	end)
	lib.CombatFrame:RegisterEvent("PLAYER_REGEN_ENABLED")
end
local tremove=tremove
local function Run(args) tremove(args,1)(unpack(args)) end
--- Executes an action as soon as combat restrictions lift
-- Action can be executed immediately if toon is out of combat
-- @tparam string|function action To be executed, Can be a function or a method name
-- @tparam[opt] mixed ... More parameters will be directly passed to action
--
function lib:OnLeaveCombat(action,...)
	if type(action)~="string" and type(action)~="function" then
		error("Usage: OnLeaveCombat (\"action\", ...): 'action' - string or function expected.", 2)
	end
	if type(action)=="string" and type(self[action]) ~= "function" then
		error("Usage: OnLeaveCombat (\"action\", ...): 'action' - method '"..tostring(action).."' not found on self.", 2)
	end
	if type(action) =="string" then
		lib._OnLeaveCombat(self,"LIBINIT_END_COMBAT",Run,{self[action],self,...})
	else
		lib._OnLeaveCombat(self,"LIBINIT_END_COMBAT",Run,{action,...})
	end
	if (not InCombatLockdown()) then
		lib.CombatFrame:GetScript("OnEvent")()
	end
end

function lib:NewSubModule(name,...)
	local obj=self:NewModule(name,...)
	-- To avoid strange interactions
	obj.OnInitialized=function()end -- placeholder
	obj.OnInitialize=function(self,...) return  self:OnInitialized(...) end
	obj.OnEnable=nil
	obj.OnDisable=nil
	return obj
end
function lib:NewSubClass(name)
	return self:NewSubModule(name,self)
end
function lib:NewTable()
	return new()
end
function lib:DelTable(t)
	return del(t)
end
function lib:CachedTableCount()
	return cached()
end
function lib:CacheStats()
	return stats()
end
--- Returns a closure to call a method as simple local function
--@usage local print=lib:Wrap("print")
function lib:Wrap(nome)
	if (nome=="Trace") then
		return function(...) lib._Trace(self,1,...) end
	end
	if (type(self[nome])=="function") then
		return function(...) self[nome](self,...) end
	else
		return nop
	end
end
function lib:GetAddon(name)
	return Ace:GetAddon(name,true)
end
function lib:GetLocale()
	return AceLocale:GetLocale(self.name)
end
function lib:Gradient(perc)
	return self:ColorGradient(perc,0,1,0,1,1,0,1,0,0)
end
function lib:ColorToString(r,g,b)
	return format("%02X%02X%02X", 255*r, 255*g, 255*b)
end
function lib:ColorGradient(perc, ...)
	if perc >= 1 then
		local r, g, b = select(select('#', ...) - 2, ...)
		return r, g, b
	elseif perc <= 0 then
		local r, g, b = ...
		return r, g, b
	end
	local num = select('#', ...) / 3
	local segment, relperc = math.modf(perc*(num-1))
	local r1, g1, b1, r2, g2, b2 = select((segment*3)+1, ...)
	return r1 + (r2-r1)*relperc, g1 + (g2-g1)*relperc, b1 + (b2-b1)*relperc
end
-- Gestione variabili
local varmeta={}
do
	local function f1(self,flag,value)
		return self:Apply(flag,value)
	end
	local function f2(self,flag,value)
		return self['Apply' .. flag](self,value)
	end
	varmeta={
		__index =
		function(table,cmd)
			local self=rawget(table,'_handler')
			if (type(self["Apply" .. cmd]) =='function') then
				rawset(table,cmd,f2)
			elseif (type(self.Apply)=='function') then
				rawset(table,cmd,f1)
			else
				rawset(table,cmd,function(...) end)
			end
			return rawget(table,cmd)
		end
	}
end
function lib:GetChatFrame(chat)
	if (chat) then
		if (lib.chats[chat]) then return lib.chats[chat] end
		for i=1,NUM_CHAT_WINDOWS do
			local frame=_G["ChatFrame" .. i]
			if (not frame) then break end
			if (frame.name==chat) then lib.chats[chat]=frame return frame end
		end
		return nil
	end
	return DEFAULT_CHAT_FRAME
end

local Myclass
---
-- Check if the unit in target hast the requested class
-- @tparam #string class Requested Class
-- @tparam #string target Requested Unit (default 'player')
-- @return #boolean true if target has the requeste class
function lib:Is(class,target)
	target=target or "player"
	if (target == "player") then
		if (not Myclass) then
			Myclass=select(2,UnitClass('player'))
		end
		return Myclass==strupper(class)
	else
		local    rc,_,unitclass=pcall(UnitClass,target)
		if (rc) then
			return unitclass==strupper(class)
		else
			return false
		end
	end
end
---
-- Parses a command from chat or from an table options handjer command
-- Internally calls AceConsole-3.0:GetArgs
-- @tparam mixed msg Can be a string (chat command) or a table (called by Ace3 Options Table Handler)
-- @tparam number n index in command list
-- @return command,subcommand,arg,full string after command
function lib:Parse(msg,n)
	if (not msg) then
		return nil
	end
	if (type(msg) == 'table' and msg.input ) then msg=msg.input end
	if (type(msg) ~= 'string') then return end
	return self:GetArgs(msg,n)
end
---
-- Parses an itemlink and returns itemId without calling API again
-- @tparam string itemlink A standard wow itemlink
-- @treturn number itemId or 0
function lib:GetItemID(itemlink)
	if (type(itemlink)=="string") then
			local itemid,context=GetItemInfoFromHyperlink(itemlink)
			return tonumber(itemid) or 0
			--return tonumber(itemlink:match("Hitem:(%d+):")) or 0
	else
			return 0
	end
end
---
-- Return the toal numner of bag slots
function lib:GetTotalBagSlots()
	local i=0
	for bag=0,NUM_BAG_SLOTS do
		i=i+GetContainerNumSlots(bag)
	end
	return i
end
---
-- Scans Bags for an item based on different criteria
--
-- All parameters are optional.
-- With no parameters ScanBags returns the first empty slot
--
-- @tparam[opt] number index is index in GetItemInfo result. 0 is a special case to match just itemid
-- @tparam[opt] number value is the value against to match. 0 is a special case for empty slot
-- @tparam[opt] number startbag and startslot are used to restart scan from the last item found
-- @tparam[opt] number startslot
-- @return Found ItemId,bag,slot,full GetItemInfo result
function lib:ScanBags(index,value,startbag,startslot)
	index=index or 0
	value=value or 0
	startbag=startbag or 0
	startslot=startslot or 1
	for bag=startbag,NUM_BAG_SLOTS do
		for slot=startslot,GetContainerNumSlots(bag),1 do
			local itemlink=GetContainerItemLink(bag,slot)
			if (itemlink) then
				if (index==0) then
					if (self:GetItemID(itemlink)==value) then
						return itemlink,bag,slot
					end
				else
					local test=CachedGetItemInfo(itemlink,index)
					if (value==test) then
						return itemlink,bag,slot
					end
				end
			elseif value==0 then
				return bag,slot

			end
		end
	end
	return false
end
--- Returns unit's health as a normalized percent value
-- @tparam string unit A standard unit name
-- @treturn number health as percent value

function lib:Health(unit)
		local totale=UnitHealthMax(unit) or 1
		local corrente=UnitHealth(unit) or 1
		if (corrente == 0) then corrente =1 end
		if (totale==0) then totale = corrente end
		local life=corrente/totale*100
		return math.ceil(life)
end

function lib:Age(secs)
		return self:TimeToStr(GetTime() - secs)
end
function lib:Mana(unit)
		local totale=UnitManaMax(unit) or 1
		local corrente=UnitMana(unit) or 1
		if (corrente == 0) then corrente =1 end
		if (totale==0) then totale = corrente end
		local life=corrente/totale*100
		return math.ceil(life)
end
function lib:IsFriend(player)
	local i
	for i =1,GetNumFriends() do
		local name,_,_,_,_ =GetFriendInfo(i)
		if (name == player) then
			return true
		end
	end
	return false
end
function lib:GetDistanceFromMe(unit)
	if not unit then return 99999 end
	local x,y=GetPlayerMapPosition(unit)
	return self:GetUnitDistance(x,y)
end
function lib:GetUnitDistance(x,y,unit)
		unit=unit or "player"
		local from={}
		local to={}
		from.x,from.y=GetPlayerMapPosition(unit)
		to.x=x
		to.y=y
		return self:GetDistance(from,to) * 10000
end
function lib:GetDistance(a,b)
--------------
-- Calculates distance betweeb 2 points given as
-- a.x,a.y and b.x,b.y
	local x=b.x - a.x
	local y=b.y -a.y
	local d=x*x + y* y
	local rc,distance=pcall(math.sqrt,d)
	if (rc) then
				return distance
		else
				return 99999
		end
end
---
-- Returns a numeric representation of version.
-- Can be overridden
-- In default incarnation assumes that version is in the form x,y,z
-- @return z+y*100+x*10000
--
function lib:NumericVersion()
	local v=tonumber(self.version)
	if (v) then return v end
	if (type(self.version) == "string") then
		local a,b,c=self.version:match("(%d*)%D?(%d*)%D?(%d*)%D*")
		a=tonumber(a) or 0
		b=tonumber(b) or 0
		c=tonumber(c) or 0
		return a*10000+b*100+c
	else
		return 0
	end
end
function lib:OnInitialized()
	print("|cff33ff99"..tostring( self ).."|r:",format(ITEM_MISSING,"OnInitialized"))
end
function lib:LoadHelp()
end
function lib:SetDbDefaults()
end
function lib:SetOptionsTable()
end
local function loadOptionsTable(self)
	local options=lib.options[self]
	self.OptionsTable={
		handler=self,
		type="group",
		childGroups="tab",
		name=options.title,
		desc=options.notes,
		args={
			gui = {
				name="GUI",
				desc=_G.CHAT_CONFIGURATION,
				type="execute",
				func="Gui",
				guiHidden=true,
			},
--@debug@
			help = {
				name="HELP",
				desc="Show help",
				type="execute",
				func="Help",
				guiHidden=true,
			},
			debug = {
				name="DBG",
				desc="Enable debug",
				type="execute",
				func="Debug",
				guiHidden=true,
				cmdHidden=true,
			},
--@end-debug@
			silent = {
				name="SILENT",
				desc="Eliminates startup messages",
				type="execute",
				func=function()
					self.db.global.silent=not self.db.global.silent
					print("Silent is now",self.db.global.silent,self.db.global.silent and "true" or "false" )
				end,
				guiHidden=true,
			},
			on = {
				name=strlower(_G.ENABLE),
				desc=_G.ENABLE .. ' ' .. options.title,
				type="execute",
				func="Enable",
				guiHidden=true,
			},
			off = {
				name=strlower(_G.DISABLE),
				desc=_G.DISABLE .. ' ' .. options.title,
				type="execute",
				func="Disable",
				guiHidden=true,
				arg='Active'
			},
		}
	}
end
local function loadDbDefaults(self)
	self.DbDefaults={
		char={
			firstrun=true,
			lastversion=0,
		},
		global={
			firstrun=true,
			lastversion=0,
			lastinterface=60200
		},
		profile={
			toggles={
					Active=true,
			},
			["*"]={},
		}
	}
	self.MenuLevels={"root"}
	self.ItemOrder=setmetatable({},{
		__index=function(table,key) rawset(table,key,1)
			return 1
		end
		}
	)
end
local function BuildHelp(self)
	local main=self.name
	for _,section in ipairs(HELPSECTIONS) do
		if (section == RELNOTES) then
			self:HF_Load(section,main..section,' ' .. tostring(self.version) .. ' (r:' .. tostring(self.revision) ..')')
		else
			self:HF_Load(section,main .. section,'')
		end
	end
end
function lib:IsFirstRun()
	return self.db.global.firstrun
end
function lib:IsNewVersion()
	return self.numericversion > self.db.global.lastnumericversion and self.db.global.lastnumericversion or false
end
function lib:IsNewTocVersion()
	return self.interface > self.db.global.lastinterface  and self.db.global.lastinterface or false
end
function lib:RegisterDatabase(dbname,defaults,profile)
	return AceDB:New(dbname,defaults,profile)
end
local function SetCommonProfile(info,...)
	local db=info.handler.db
	for k,v in pairs(db.sv.profileKeys) do
		db.sv.profileKeys[k]="Default"
	end
	db:SetProfile("Default")
end
local function PurgeProfiles(info,...)
	local profiles=new()
	local used=new()
	local db=info.handler.db
	db:GetProfiles(profiles)
	for k,v in pairs(db.sv.profileKeys) do
		used[v]=true
	end
--@debug@
	DevTools_Dump(profiles)
	DevTools_Dump(used)
--@end-debug@
	for _,v in ipairs(profiles) do
		if not used[v] then
			db:DeleteProfile(v)
		end
	end
	del(used)
	del(profiles)

end
local function SetupProfileSwitcher(tbl,addon)
	local profiles=tbl.handler:ListProfiles({args="both"})
	local default=profiles.Default or "Default"
	wipe(profiles)
	tbl.args.UseDefault_Desc={
		order=900,
		type='description',
		name="\n"..format(L['UseDefault_Desc'],default)
	}
	tbl.args.UseDefault={
		order=910,
		type='execute',
		func=SetCommonProfile,
		name=format(L['UseDefault1'],default),
		desc=format(L['UseDefault2'],default),
		width="double",
	}
	tbl.args.Purge_Desc={
		order=920,
		type='description',
		--name="forcedescname",
		name="\n"..L['Purge_Desc'],
	}
	tbl.args.Purge={
		order=930,
		type='execute',
		func=PurgeProfiles,
		name=L['Purge1'],
		desc=L['Purge2'],
		width="double",
	}
end
function lib:OnInitialize(...)
	self.numericversion=self:NumericVersion() -- Initialized now becaus NumericVersion could be overrided
	--CachedGetItemInfo=self:GetCachingGetItemInfo()
	loadOptionsTable(self)
	loadDbDefaults(self)
	self:SetOptionsTable(self.OptionsTable) --hook
	self:SetDbDefaults(self.DbDefaults) -- hook
	local options=lib.options[self]
	self.version=self.version or options.version
	self.prettyversion=self.prettyversion or options.prettyversion
	self.revision=self.revision or options.revision
	if (AceDB and not self.db) then
		self.db=AceDB:New(options.DATABASE,nil,options.profile)
		dprint(self.db:GetCurrentProfile())
	end
	if self.db then
		self.db:RegisterDefaults(self.DbDefaults)
		if (not self.db.global.silent) then
			self:Print(format("Version %s %s loaded (%s)",
				self:Colorize(options.version,'green'),
				self:Colorize(format("(Revision: %s)",options.revision),"silver"),
				"Disable message with /" .. strlower(options.ID) .. " silent")
			)
		end
		self:SetEnabledState(self:GetBoolean("Active"))
	else
		self.db=setmetatable({},{
			__index=function(t,l)
				assert(false,"You need AceDB-3.0 in order to use database")
			end
			}
		)
		self:SetEnabledState(true)
	end
	-- I have for sure some library that needs to be intialized Before the addon
	for _,library in self:IterateEmbeds(self) do
		local lib=LibStub(library)
		if (lib.OnEmbedPreInitialize) then
			lib:OnEmbedPreInitialize(self)
		end
	end

	self.help=setmetatable(
			{},
			{__index=function(table,key)
					rawset(table,key,"")
					return rawget(table,key)
					end
			}
	)
	--===============================================================================
	-- Calls initialization Callback
	local ignoreProfile=self:OnInitialized(...)
	--===============================================================================
	if (not self.OnDisabled) then
		self.OptionsTable.args.on=nil
		self.OptionsTable.args.off=nil
		self.OptionsTable.args.standby=nil
	end
	if (type(self.LoadHelp)=="function") then self:LoadHelp() end
	local main=options.name
	BuildHelp(self)
	if AceConfig and not options.nogui then
		AceConfig:RegisterOptionsTable(main,self.OptionsTable,{main,strlower(options.ID)})
		self.CfgDlg=AceConfigDialog:AddToBlizOptions(main,main )
		if (not ignoreProfile and not options.noswitch) then
			if (AceDBOptions) then
				local profileOpts=AceDBOptions:GetOptionsTable(self.db)
				self.ProfileOpts={} -- We dont want to propagate this change to all ace3 addons
				for k,v in pairs(profileOpts) do
					if k=='args' then
						self.ProfileOpts.args={}
						for k2,v2 in pairs(v) do
							self.ProfileOpts.args[k2]=v2
						end
					else
						self.ProfileOpts[k]=v
					end
				end
				titles.PROFILE=self.ProfileOpts.name
				self.ProfileOpts.name=self.name
				if options.enhancedprofile then
					SetupProfileSwitcher(self.ProfileOpts,self)
				end
				local profile=main..PROFILE
			end
			AceConfig:RegisterOptionsTable(main .. PROFILE,self.ProfileOpts)
			AceConfigDialog:AddToBlizOptions(main .. PROFILE,titles.PROFILE,main)
		end
	else
		self.OptionsTable.args.gui=nil
	end
	if (self.help[RELNOTES]~='') then
		self.CfgRel=AceConfigDialog:AddToBlizOptions(main..RELNOTES,titles.RELNOTES,main)
	end
	if AceDB then
		self:UpdateVersion()
	end
end
function lib:UpdateVersion()
	if (type(self.db.char) == "table") then
		self.db.char.lastversion=self.numericversion
		self.db.char.firstun=false
	end
	if (type(self.db.global)=="table") then
		self.db.global.lastversion=self.numericversion
		self.db.global.firstrun=false
		self.db.global.lastinterface=self.interface
	end
end

-- help related functions
function lib:HF_Push(section,text)
	if section then section=titles[section] end
	section=section or self.lastsection or RELNOTES
	self.lastsection=section
	self.help[section]=self.help[section]  .. '\n' .. text
end
local getlibs
do
	local libs={}
		function lib:HF_Lib(libname)
				local o,minor=LibStub(libname,true)
				if (o and libs) then
						if (not libs[o] or libs[o] <minor) then
								libs[libname]=minor
						end
				end
		end
		function getlibs(self)
				local appo={}
				if (not libs) then return end
				for i,_ in pairs(libs) do
						table.insert(appo,i)
				end
				table.sort(appo)
				for _,libname in pairs(appo) do
						local minor=libs[libname]
						self:HF_Pre(format("%s release: %s",self:Colorize(libname,'green'),self:Colorize(minor,'orange')),LIBRARIES)
				end
				libs=nil
		end
end

function lib:HF_Toggle(flag,description)
	flag=C(format("/%s toggle %s: ",strlower(lib.options[self].ID),flag),'orange') ..C(description,'white')
	self:HF_Push(TOGGLES,"\n" .. C(flag,'orange'))
end

function lib:HF_Title(text,section)
	self:HF_Push(section,C(text or '','yellow') .. "\n")
end
function lib:HF_Command(text,description,section)
	self:HF_Push(section,C(text or '','orange') .. ':' ..  C(description or '','yellow') .. "\n")
end

function lib:HF_Paragraph(text,section)
	self:HF_Push(section,"\n"..C(text,'green'))
end
function lib:HF_CmdA(command,description,tooltip)
	self:HF_Push(nil,
	C('/' .. command,'orange') .. ' : ' .. (description or '') .. '\n' .. C(tooltip or '','yellow'))
end
function lib:HF_Cmd(command,description,tooltip)
	command=lib.options[self].ID .. ' ' .. command
	self:HF_CmdA(command,description,tooltip)
end
function lib:HF_Pre(testo,section)
	self:HF_Push(section,testo)
end
function lib:Wiki(testo,section)
	section=section or self.lastsection or RELNOTES
	self.lastsection=section
	local fmtbullet=" * %s\n"
	local progressive=1
	local fmtnum=" %2d. %s\n"
	local fmthead1="|cff" .. C.Orange  .."%s|r\n \n \n"
	local fmthead2="|cff" .. C.Yellow  .."%s|r\n \n"
	local text=''
	for line in testo:gmatch("(%C*)%c+") do
		line=line:gsub("^ *","")
		line=line:gsub(" *$","")
		local i,j= line:find('^%=+')
		if (i) then
			if (j==1) then
				text=text .. fmthead1:format(line:sub(j+1,-j-1))
			else
				text=text .. fmthead2:format(line:sub(j+1,-j-1))
			end
		else
			local i,j= line:find('^%*+')
			if (i) then
				text=text.. fmtbullet:format(line:sub(j+1))
			else
				local i,j= line:find('^#+')
				if (i) then
					text=text .. fmtnum:format(progressive,line:sub(j+1))
					progressive=progressive + 1
				else
					text=text .. line.."\n"
				end
			end
		end
	end
	self.help[section]=self.help[section]  .. '\n' .. text
end

function lib:RelNotes(major,minor,revision,t)
	local fmt=self:Colorize("Release note for %d.%d.%s",'Yellow') .."\n%s"
	local lines={}
	local spacer=""
	local maxpanlen=70
	lines={strsplit("\n",t)}
	local max=5
	for i,tt in ipairs(lines) do
		local prefix,text=tt:match("^(%a+):(.*)")
		if (prefix == "Fixed" or prefix=="Fix") then
			prefix=self:Colorize("Fix: ",'Red')
			spacer="       "
		elseif (prefix == "Feature") then
			prefix=self:Colorize("Feature: ",'Green')
			spacer=             "         "
		else
			text=tt
			prefix=spacer
		end
		local tta=""
		tt=text
		while (tt:len() > maxpanlen)  do
			local p=tt:find("[%s%p]",maxpanlen -10) or maxpanlen
			tta=tta..prefix..tt:sub(1,p) .. "\n"
			prefix=spacer
			tt=tt:sub(p+1)
		end
		tta=tta..prefix..tt
		tta=tta:gsub("Upgrade:",self:Colorize("Upgrade:",'Azure'))
		lines[i]=tta:gsub("Example:",self:Colorize("Example:",'Orange'))
		max=max-1
		if (max<1) then
			break
		end
	end
	self:HF_Push(RELNOTES,fmt:format(major,minor,revision,strjoin("\n",unpack(lines))))
end

function lib:HF_Load(section,optionname,versione)
-- Creazione pannello di help
-- Livello due del
	if (section == LIBRARIES) then
		getlibs(self)
	end
	local testo =self.help[section]
	--debug(section)
	--debug(optionname)
	--debug(self.title)
	if (testo ~= '') then
		AceConfig:RegisterOptionsTable(optionname, {
			name = lib.options[self].title .. (versione or ""),
			type = "group",
			args = {
				help = {
					type = "description",
					name = testo,
					fontSize='medium',
				},
			},
		})
		AceConfigDialog:SetDefaultSize(optionname, 600, 400)
	end
end
-- var area
local function getgroup(self)
	local group=self.OptionsTable
	local m=self.MenuLevels
	for i=2,#m do
			group=group.args[self.MenuLevels[i]]
	end
	if (type(group) ~= "table") then
			group={}
	end
	return group
end
local function getorder(self,group)
	local i=self.ItemOrder[group.name]+1
	self.ItemOrder[group.name]=i
	return i
end
local function toflag(...)
	local appo=''
	for i=1,select("#",...) do
		appo=appo .. tostring(select(i,...))
	end
		return appo:gsub("%W",'')
end
function lib:EndLabel()
	local m=self.MenuLevels
	if (#m > 1) then
			table.remove(m)
	end
end

--self:AddLabel("General","General Options",C.Green)
function lib:AddLabel(title,description,stringcolor)
	self:EndLabel()
	description=description or title
	stringcolor=stringcolor or C.yellow
	local t=self:AddSubLabel(title,description,stringcolor)
	t.childGroups="tab"
	self:AddSeparator(description)
	return t
end
--self:AddSubLabel("Local","Local Options",C.Green)
function lib:AddSubLabel(title,description,stringcolor)
	local m=self.MenuLevels
	description=description or title
	stringcolor=stringcolor or C.orange
	local group=getgroup(self)
	local flag=toflag(group.name,title)
	group.args[flag]={
			name="|cff" .. stringcolor .. title .. "|r",
			desc=description,
			type="group",
			cmdHidden=true,
			args={},
			order=getorder(self,group),
	}
	table.insert(m,flag)
	return group.args[flag]
end

--self:AddText("Testo"[,texture[,height[,width[,texcoords]]]])
function lib:AddText(text,image,imageHeight,imageWidth,imageCoords)
	local group=getgroup(self)
	local flag=toflag(group.name,text)
	local t={
			name=text,
			type="description",
			image=image,
			imageHeight=imageHeight,
			imageWidth=imageWidth,
			imageCoords=imageCoords,
			desc=text,
			order=getorder(self,group),

	}
	group.args[flag]=t
	return t
end

--self:AddToggle("AUTOLEAVE",true,"Quick Battlefield Leave","Alt-Click on hide button in battlefield alert leaves the queue")
function lib:AddBoolean(...) return self:AddToggle(...) end
function lib:AddToggle(flag,defaultvalue,name,description,icon)
	description=description or name
	local group=getgroup(self)
	local t={
			name=name,
			type="toggle",
			get="OptToggleGet",
			set="OptToggleSet",
			desc=description,
			width='full',
			arg=flag,
			cmdHidden=true,
			icon=icon,
			order=getorder(self,group),
	}
	lib.toggles[self][flag]=t
	group.args[flag]=t
	if (self.db.profile.toggles[flag]== nil) then
		self.db.profile.toggles[flag]=defaultvalue
	end
	return t
end

-- self:AddEdit("REFLECTTO",1,{a=1,b=2},"Whisper reflection receiver:","All your whispers will be forwarded to this guy")
function lib:AddSelect(flag,defaultvalue,values,name,description)
	description=description or name
	local group=getgroup(self)
	local t={
			name=name,
			type="select",
			get="OptToggleGet",
			set="OptToggleSet",
			desc=description,
			width="full",
			values=values,
			arg=flag,
			cmdHidden=true,
			order=getorder(self,group)
	}
	group.args[flag]=t
	if (self.db.profile.toggles[flag]== nil) then
		self.db.profile.toggles[flag]=defaultvalue
	end
	lib.toggles[self][flag]=t
	return t
end
function lib:AddMultiSelect(flag,defaultvalue,...)
	local t=self:AddSelect(flag,defaultvalue,...)
	t.type="multiselect"
	if type(self.db.profile.toggles[flag])~="table" then
		self.db.profile.toggles[flag]={}
	end
	if type(self.db.profile.toggles[flag]._default)=="nil" then
		self.db.profile.toggles[flag]=defaultvalue
		self.db.profile.toggles[flag]._default=true
	end
	return t
end
--self:AddSlider("RESTIMER",5,1,10,"Enable res timer","Shows a timer for battlefield resser",1)
function lib:AddRange(...) return self:AddSlider(...) end
function lib:AddSlider(flag,defaultvalue,min,max,name,description,step)
	description=description or name
	min=min or 0
	max=max or 100
	local group=getgroup(self)
	local isPercent=nil
	if (type(step)=="boolean") then
		isPercent=step
		step=nil
	else
		step=tonumber(step) or 1
	end
	local t={
		name=name,
		type="range",
		get="OptToggleGet",
		set="OptToggleSet",
		desc=description,
		width="full",
		arg=flag,
		step=step,
		isPercent=isPercent,
		min=min,
		max=max,
		order=getorder(self,group),
	}
	group.args[flag]=t
	if (self.db.profile.toggles[flag]== nil) then
		self.db.profile.toggles[flag]=defaultvalue
	end
	lib.toggles[self][flag]=t
	return t
end
-- self:AddEdit("REFLECTTO","","Whisper reflection receiver:","All your whispers will be forwarded to this guy","How to use it")
function lib:AddEdit(flag,defaultvalue,name,description,usage)
	description=description or name
	usage = usage or description
	local group=getgroup(self)
	local t={
			name=name,
			type="input",
			get="OptToggleGet",
			set="OptToggleSet",
			desc=description,
			arg=flag,
			usage=usage,
			order=getorder(self,group),

	}
	group.args[flag]=t
	if (self.db.profile.toggles[flag]== nil) then
			self.db.profile.toggles[flag]=defaultvalue
	end
	lib.toggles[self][flag]=t
	return t
end

-- self:AddAction("openSpells","Opens spell panel","You can choose yoru spells in spell panel")
function lib:AddAction(method,label,description,private)
	label=label or method
	description=description or label
		local group=getgroup(self)
		local t={
			func=method,
			name=label,
			type="execute",
			desc=description,
			confirm=false,
			cmdHidden=true,
			order=getorder(self,group)
		}
	if (private) then t.hidden=true end
	group.args[strlower(label)]=t
	lib.toggles[self][method]=t
	return t
end

function lib:AddPrivateAction(method,name,description)
	return self:AddAction(method,name,description,true)
end
function lib:AddKeyBinding(flag,name,description)
	name=name or strlower(name)
	description=description or name
	local group=getgroup(self)
	local t={
		name=name,
		type="keybinding",
		get="OptToggleGet",
		set="OptToggleSet",
		desc=description,
		arg=flag,
		order=getorder(self,group)
	}
	group.args[flag]=t
	lib.toggles[self][flag]=t
	return t
end
function lib:AddTable(flag,table)
	local group=getgroup(self)
	group.args[flag]=table
	lib.toggles[self][flag]=table
end
local function OpenCmd(self,info,args)
	return self[info.arg](self,args,strsplit(' ',args))
end
function lib:AddOpenCmd(command,method,description,arguments,private)
	method=method or command
	description=description or command
	local group=getgroup(self)
	if (not private) then
		local command=C('/' .. lib.options[self].ID .. ' ' .. command .. " (" .. description .. ")" ,'orange')
		local t={
			name=command,
			type="description",
			order=getorder(self,group),
			fontSize='medium',
			width='full'
		}
		group.args[command .. 'title']=t
	end
	local t={
		name=command,
		type="input",
		arg=method,
		get=function(...) end,
		set=function(...) return OpenCmd(self,...) end,
		desc=description,
		order=getorder(self,group),
		guiHidden=true,
		hidden=private
	}
	if (type(arguments)=="table") then
		local validate={}
		for _,v in pairs(arguments) do
			validate[v]=v
		end
		t.values=validate
		t.type="select"
	end
	self.OptionsTable.args[command]=t

	return t
end
function lib:AddPrivateOpenCmd(command,method,description,arguments)
	return self:AddOpenCmd(command,method,description,arguments,true)
end
function lib:GetVarInfo(flag)
	return lib.toggles[self][flag]
end

--self:AddSubCmd(flagname,method,label,description)
function lib:AddSubCmd(flag,method,name,description,input)
	method=method or flag
	name=name or flag
	description=description or name
	local group=getgroup(self)
	debug("AddSubCmd " .. flag .. " for " .. method)
	local t={
		func=method,
		name=name,
		type="execute",
		input=input,
		desc=description,
		confirm=true,
		order=getorder(self,group),
		guiHidden=true,
	}
	group.args[flag]=t
	return t
end



--self:AddChatCmd(method,label,description)
function lib:AddChatCmd(method,label,description)
	if (not self.RegisterChatCommand) then
		LibStub("AceConsole-3.0"):Embed(self)
	end
	label=label or method
	self:RegisterChatCommand(label,method)
	description=description or label

	local group=getgroup(self)
	local t={
			name=C('/' .. label ..  " (" .. description .. ")",'orange'),
			type="description",
			order=getorder(self,group),
			fontSize="medium",
			width="full"
	}
	group.args[label .. 'title']=t
	return t
end

--self:AddSeparator(text)

function lib:AddSeparator(text)
	local group=getgroup(self)
	local i=getorder(self,group)
	local flag=group.name .. i
	flag=flag:gsub('%W','')
	local t={
			name=text,
			type="header",
			order=i,
	}
	group.args[flag]=t
	return t
end

function lib:OnEmbedEnable(first)
end

function lib:OnEmbedDisable()
end


function lib:OnEnable()
	if (self.OnEnabled) then
		if (not self.db.global.silent) then
			self:Print(C(VIDEO_OPTIONS_ENABLED,"green"))
		end
		pcall(self.OnEnabled,self,lib.options[self].first)
		lib.options[self].first=nil
	end
end
function lib:OnDisable(...)
	if (self.OnDisabled) then
		if (not self.db.global.silent) then
			self.print(C(VIDEO_OPTIONS_DISABLED,'red'))
		end
		pcall(self.OnDisabled,self,...)
	end
end
local function _GetMethod(target,prefix,func)
	if (func == 'Start' or func == 'Stop') then return end
	local method=prefix .. func
	if (type(target[method])== "function") then
			return method
	elseif (type(target["_" .. prefix])) then
			return "_" .. prefix
	end
end
function lib:StartAutomaticEvents()
	for k,v in pairs(self) do
		if (type(v)=='function') then
			if (k:sub(1,3)=='Evt') then
				self:RegisterEvent(k:sub(4),k)
			end
		end
	end
end
function lib:StopAutomaticEvents(ignore)
	for k,v in pairs(self) do
		if (type(v)=='function') then
			if (k:sub(1,3)=='Evt') then
				if (ignore and k==ignore or k:sub(4)==ignore) then
					--a kickstart event not to be disabled
				else
					self:UnregisterEvent(k:sub(4))
				end
			end
		end
	end
end
function lib:Dprint(...)
end
function lib:Notify(...)
	return self:CustomPrint(C.orange.r,C.orange.g,C.orange.b, nil, nil, ' ', ...)
end
function lib:Debug()
	self.DebugOn=not self.DebugOn
	self:Print("Debug:",self.DebugOn and on or off)
	if self.DebugOn then
		self.Dprint=dprint
	else
		self.Dprint=nop
	end
end

function lib:Colorize(stringa,colore)
	return C(stringa,colore) .. "|r"
end
function lib:GetTocVersion()
	return select(4,GetBuildInfo())
end
function lib:Toggle()
	if (self:IsEnabled()) then
		self:Disable()
	else
		self:Enable()
	end
end
function lib:Vars()
	return pairs(self.db.profile.toggles)
end
function lib:SetBoolean(flag,value)
	if (value) then
		value=true
	else
		value=false
	end
	self.db.profile.toggles[flag]=value
	return not value
end
function lib:GetBoolean(flag)
	if (self.db.profile.toggles[flag]) then
		return true
	else
		return false
	end
end
lib.GetToggle=lib.GetBoolean -- alias
function lib:GetNumber(flag,default)
	return tonumber(self:GetSet(flag) or default or 0)
end
function lib:GetString(flag,default)
	return tostring(self:GetSet(flag) or default or '')
end

function lib:PrintBoolean(flag)
	if (type(flag) == "string") then
		flag=self:GetBoolean(flag)
	end
	if (flag) then
		return on
	else
		return off
	end
end
function lib:GetSet(...)
	local flag,value=select(1,...)
	if (select('#',...) == 2) then
		self.db.profile.toggles[flag]=value
	else
		return self.db.profile.toggles[flag]
	end
end
function lib:GetIndexedVar(flag,index)
	local rc=GetVar(flag)
	if index and type(rc)=="table" then
		return rc[index]
	else
		return rc
	end

end
function lib:GetVar(flag)
	return self:GetSet(flag)
end
function lib:SetVar(flag,value)
	return self:GetSet(flag,value)
end
--- Simulates a configuration  variable change.
--
-- Generates Apply* events if needed
-- @tparam string flag Variable name
function lib:Trigger(flag)
	local info=self:GetVarInfo(flag)
	if (info) then
		local value=info.type=="toggle" and self:GetBoolean(flag) or self:GetVar(flag)
		self._Apply[flag](self,flag,value)
	end

end
function lib:OptToggleSet(info,value,extra)
	local flag=info.option.arg
	local tipo=info.option.type

	if (tipo=="toggle") then
		self:SetBoolean(flag,value)
	elseif (tipo=="multiselect") then
		self.db.profile.toggles[flag][value]=extra
	else
		self:GetSet(flag,value)
	end
	if (self:IsEnabled()) then
		self._Apply[flag](self,flag,value)
	end
end
function lib:OptToggleGet(info,extra)
	local flag=info.option.arg
	local tipo=info.option.type
	if (tipo=="toggle") then
		return self:GetBoolean(flag)
	elseif (tipo=="multiselect") then
		if type(self.db.profile.toggles[flag])~="table" then
			self.db.profile.toggles[flag]={}
		end
		return self.db.profile.toggles[flag][extra]
	else
		return self:GetSet(flag)
	end
end
function lib:ApplySettings()
	if (type(self.ApplyAll)=="function") then
		self:ApplyAll()
	else
		for i,v in self:Vars() do
			self._Apply[i](self,i,v)
		end
	end
end
local neveropened=true
function lib:Gui(info)
	if (AceConfigDialog and AceGUI) then
		if (neveropened) then
			InterfaceAddOnsList_Update()
			neveropened=false
		end
		InterfaceOptionsFrame_OpenToCategory(self.CfgDlg)
	else
		self:Print("No GUI available")
	end
end

function lib:Help(info)
	if (AceConfigDialog and AceGUI) then
		if (neveropened) then
			InterfaceAddOnsList_Update()
			neveropened=false
		end
		InterfaceOptionsFrame_OpenToCategory(self.CfgRel)
	else
		self:Print("No GUI available")
	end
end
function lib:Long(msg) C:OnScreen('Yellow',msg,20) end
function lib:Onscreen_Orange(msg) C:OnScreen('Orange',msg,2) end
function lib:Onscreen_Purple(msg) C:OnScreen('Purple',msg,8) end
function lib:Onscreen_Yellow(msg) C:OnScreen('Yellow',msg,1) end
function lib:Onscreen_Azure(msg) C:OnScreen('Azure',msg,1) end
function lib:Onscreen_Red(msg) C:OnScreen('Red',msg,1) end
function lib:Onscreen_Green(msg) C:OnScreen('Green',msg,1) end
function lib:OnScreen(color,...) C:OnScreen(color,strjoin(' ',tostringall(...))) end
function lib:TimeToStr(time) -- Converts time data to a string format
	local p,s,m,h;
	if (not time) then
		return ("0:00")
	end
	if (time < 0) then
		time=abs(time)
		p='-'
	else
		p=''
	end
	s = floor(mod(time, 60));
	m = floor(time/ 60);
	if (m > 59) then
		h=floor(m/60)
		m=floor(mod(m,60))
	end
	if (h) then
		return format("%s%d:%02d:%02d",p,h,m,s)
	else
		return format("%s%d:%02d",p,m,s)
	end
end

function lib:GetColorTable()
	return C
end
-- In case of upgrade, we need to redo embed for ALL Addons
-- This function get called on addon creation
-- Anything I define here is immediately available to addon code
function lib:Embed(target)
	-- All methods are pulled in via metatable in order to not pollute addon table
	local mt=getmetatable(target)
	if not mt then mt={__tostring=function(me) return me.name end} end
	mt.__index=lib.mixins
	setmetatable(target,mt)
	target._Apply=target._Apply or {}
	target._Apply._handler=target
	for k,v in pairs(self) do
		if type(v)=="string" or type(v)=="number" then pp (self,k,v) end
	end
	setmetatable(target._Apply,varmeta)
	lib.mixinTargets[target] = true
end

local function kpairs(t,f)
	local a = new()
	for n in pairs(t) do table.insert(a, n) end
	table.sort(a, f)
	local i = 0      -- iterator variable
	local iter = function ()   -- iterator function
		i = i + 1
		if a[i] == nil then
				del(a)
				return nil
		else
				local k=a[i]
				a[i]=nil -- Should optimize memory usage
				return k, t[k]
		end
	end
	return iter
end
if (not _G.kpairs) then
		_G.kpairs=kpairs
end
function lib:getKpairs()
	return kpairs
end
-- This metatable is used to generate a sorted proxy to an hashed table.
-- It should not used directly
lib.mt={__metatable=true,__version=MINOR_VERSION}
local mt=lib.mt
function mt:__index(k)
	if k=="n" then
		return #mt.keys[self.__source]
	end
	return self.__source[k]
end
function mt:__len()
	return #self.__keys
end
function mt:__newindex(k,v)
	local pos=#self.__keys+1
	for i,x in ipairs(self.__keys) do
		if x>k then
			pos=i
			break;
		end
	end
	if (k:sub(1,2)~="__") then
		table.insert(self.__keys,pos,k)
	end
	self.__source[k]=v -- We want to trigger metamethods on original table
end
function mt:__call()
	do
		local current=0
		return function(unsorted,i)
			current=current+1
			local k=self.__keys[current]
			if k then return k,self.__source[k] end
		end,self,0
	end
end
function lib:GetSortedProxy(table)
	local proxy=setmetatable({__keys={},__source=table,__metatable=true},mt)
	for k,v in pairs(table) do
		proxy[k]=v
	end
	return proxy
end

function lib:ScheduleLeaveCombatAction(method, ...)
	return self:OnLeaveCombat(method,...)
end

--- Generates and executes a coroutine with configurable interval and combat status
-- If called for already running coroutine changes the interval and the combat status
-- @tparam number interval between steps
-- @tparam string|function action To be executed, Can be a function or a method name
-- @tparam[opt] bool
--
function lib:coroutineExecute(interval,func,safeForCombat)
	if type(func)=="string" then
		func=self[func]
	end
	assert(type(func) =="function","coroutineExecute arg1 was not convertible to a function " .. tostring(func))
	local c=lib.coroutines[func]
	c.combatSafe=safeForCombat
	c.interval=interval
	c.obj=self
	if type(c.co)=="thread" and coroutine.status(c.co)=="suspended" then print("Already running",func) return end
	c.co=coroutine.create(func)
	c.paused=false
	c.repeater=function()
		if not c.combatSafe and InCombatLockdown() then
			c.waiting=true
			return
		end
		if c.paused then return end
		local rc,res=pcall(coroutine.resume,c.co,c.obj)
		if rc and res then
			C_Timer.After(c.interval,c.repeater)
		else
			c=nil
		end
	end
	c.repeater()
	return c
end
function lib:coroutinePause(func)
	if type(func)=="string" then
		func=self[func]
	end
	local co=rawget(lib.coroutines,func)
	if co then
		co.paused=true
	end
end
function lib:coroutineRestart(func)
	if type(func)=="string" then
		func=self[func]
	end
	local co=rawget(lib.coroutines,func)
	if co then
		co.paused=false
		pcall(co.repeater)
	end
end
if not lib.secureframe then
	lib.secureframe=CreateFrame("Button",nil,nil,"StaticPopupButtonTemplate,SecureActionButtonTemplate")
	lib.secureframe:Hide()
end
local function StopSpellCasting(this)
	local b2=_G[this:GetName().."Button2"]
	local AC=lib.secureframe
	AC:SetParent(b2)
	AC:SetAllPoints()
	AC:SetText(b2:GetText())
	AC:SetAttribute("type","stop")
	AC:SetScript("PostClick",function() b2:Click() end)
	AC:Show()
end
local function StopSpellCastingCleanup(this)
	local AC=lib.secureframe
	AC:SetParent(nil)
	AC:Hide()

end
local StaticPopupDialogs=StaticPopupDialogs
local StaticPopup_Show=StaticPopup_Show
--- Show a popup
-- Display a popup message with Accept and optionally Cance button
-- @tparam string msg Message to be shown
-- @tparam[opt] number timeout In seconds, if omitted assumes 60
-- @tparam[opt] func OnAccept Executed when clicked on Accept
-- @tparam[opt] func OnCancel Executed when clicked on Cancel (if nill, Cancel button is not shown)
-- @tparam[opt] mixed data Passed to the callbacl function
-- @tparam[opt] bool StopCasting If true, when the popup appear will stop any running casting.
-- Useful to ask confirmation before performing a programmatic initiated spellcasting
function lib:Popup(msg,timeout,OnAccept,OnCancel,data,StopCasting)
	if InCombatLockdown() then
		return self:ScheduleLeaveCombatAction("Popup",msg,timeout,OnAccept,OnCancel,data,StopCasting)
	end
	msg=msg or "Something strange happened"
	if type(timeout)=="function" then
		StopCasting=data
		data=OnCancel
		OnAccept=timeout
		timeout=60
	end
	StaticPopupDialogs["LIBINIT_POPUP"] = StaticPopupDialogs["LIBINIT_POPUP"] or
	{
	text = msg,
	showAlert = true,
	timeout = timeout or 60,
	exclusive = true,
	whileDead = true,
	interruptCinematic = true
	};
	local popup=StaticPopupDialogs["LIBINIT_POPUP"]
	if StopCasting then
		popup.OnShow=StopSpellCasting
		popup.OnHide=StopSpellCastingCleanup
	else
		popup.OnShow=nil
		popup.OnHide=nil
	end
	popup.text=msg
	popup.OnCancel=nil
	popup.OnAccept=OnAccept
	popup.button1=ACCEPT
	popup.button2=nil
	if (OnCancel) then
		if (type(OnCancel)=="function") then
			popup.OnCancel=OnCancel
		end
		popup.button2 = CANCEL
	else
		popup.button1=OKAY
	end
	StaticPopup_Show("LIBINIT_POPUP",nil,nil,data);
end
-- Interface widgets
local factory={} --#factory
do
	local nonce=0
	local GetTime=GetTime
	local function SetScript(this,...)
		this.child:SetScript(...)
	end
	local function SetStep(this,value)
		this:SetObeyStepOnDrag(true)
		this:SetValueStep(value)
		this:SetStepsPerPage(1)
	end
	function factory:Slider(father,min,max,current,message,tooltip)
		if type(message)=="table" then
			tooltip=message.desc
			message=message.name
		end
		local name=tostring(GetTime()*1000) ..nonce
		nonce=nonce+1
		local sl = CreateFrame('Slider',name, father, 'OptionsSliderTemplate')
		sl:SetWidth(128)
		sl:SetHeight(20)
		sl:SetOrientation('HORIZONTAL')
		sl:SetMinMaxValues(min, max)
		sl:SetValue(current)
		sl.SetStep=SetStep
		sl.Low=_G[name ..'Low']
		sl.Low:SetText(min)
		sl.High=_G[name .. 'High']
		sl.High:SetText(max)
		sl.Text=_G[name.. 'Text']
		sl.Text:SetText(message)
		sl.OnValueChanged=function(this,value)
			if (not this.unrounded) then
				value = math.floor(value)
			end
			if (this.isPercent) then
				this.Text:SetFormattedText('%d%%',value)
			else
				this.Text:SetText(value)
			end
			return value
		end
		sl.SetText=function(this,value) this.Text:SetText(value) end
		sl.SetFormattedText=function(this,...) this.Text:SetFormattedText(...) end
		sl.SetTextColor=function(this,...) this.Text:SetTextColor(...) end
		sl:SetScript("OnValueChanged",sl.OnValueChanged)
		sl.tooltipText=tooltip
		return sl
	end
	function factory:Checkbox(father,current,message,tooltip)
		if type(message)=="table" then
			tooltip=message.desc
			message=message.name
		end
		local name=tostring(GetTime()*1000) ..nonce
		nonce=nonce+1
		local frame=CreateFrame("Frame",nil,father)
		local ck=CreateFrame("CheckButton",name,frame,"ChatConfigCheckButtonTemplate")
		frame.SetScript=SetScript
		frame.child=ck
		ck:SetPoint('TOPLEFT')
		ck.Text=_G[name..'Text']
		ck.Text:SetText(message)
		ck:SetChecked(current)
		ck.tooltip=tooltip
		frame:SetWidth(ck:GetWidth()+ck.Text:GetWidth()+2)
		frame:SetHeight(ck:GetHeight())
		return frame
	end
	function factory:Dropdown(father,current,list,message,tooltip)
		if type(message)=="table" then
			tooltip=message.desc
			message=message.name
		end
		do
		local dd=CreateFrame("Frame",nil,father)
		if (tooltip) then
			dd.tooltip=tooltip
			dd:SetScript("OnEnter",function(self)
					GameTooltip:SetOwner(self, "ANCHOR_RIGHT");
					GameTooltip:SetText(self.tooltip, nil, nil, nil, nil, (self.tooltipStyle or true));
				end
			)
		end
		dd:SetScript("OnLeave",function() GameTooltip:Hide() end)
		dd.text=dd:CreateFontString(nil,"ARTWORK","GameFontHighlight")
		function dd:SetText(...)
			self.text:SetText(...)
		end
		function dd:SetFormattedText(...)
			self.text:SetFormattedText(...)
		end
		function dd:SetTextColor(...)
			self.text:SetTextColor(...)
		end
		function dd:OnChange() end
		function dd:OnValueChanged(this,index,value)
			value=value or index
			UIDropDownMenu_SetSelectedID(dd,index)
			return self:OnChange(value)
		end
		function dd:SetOnChange(func)
			self.OnChange=func
		end
		dd.list=list
		local name=tostring(GetTime()*1000) ..nonce
		nonce=nonce+1
		dd.dropdown=CreateFrame('Frame',name,father,"UIDropDownMenuTemplate")
		UIDropDownMenu_Initialize(dd, function(...)
			local i=0
			for k,v in pairs(dd.list) do
				i=i+1
				local info=UIDropDownMenu_CreateInfo()
				info.text=v
				info.value=v
				info.func=function(...) return dd:OnValueChanged(...) end
				info.arg1=i
				info.arg2=v
				UIDropDownMenu_AddButton(info,1)
			end
		end)
		UIDropDownMenu_SetWidth(dd, 100);
		UIDropDownMenu_SetButtonWidth(dd, 124)
		UIDropDownMenu_SetSelectedID(dd, 1)
		UIDropDownMenu_JustifyText(dd, "LEFT")
		end
	end
end
function lib:GetFactory()
	return factory
end
local meta={__index=_G,
__newindex=function(t,k,v)
	assert(type(_G[k]) == 'nil',"Attempting to override global " ..k)
	return rawset(t,k,v)
end
}
function lib:SetCustomEnvironment(new_env)
	local old_env = getfenv(2)
	if old_env==new_env then return end
	if getmetatable(new_env)==meta then return end
	if not getmetatable(new_env) then
		if not new_env.print then new_env.print=dprint end
		setmetatable(new_env,meta)
		new_env.dprint=dprint
	else
		assert(false,"new_env already has metatable")
	end
	setfenv(2, new_env)
end
--- reembed routine
-- Prepares the mixins table
lib.mixins=lib.mixins or {}
wipe(lib.mixins)
for name,method in pairs(lib) do
	if type(method)=="function" and name~="NewAddon" and name~="GetAddon" and name:sub(1,1)~="_" then
		lib.mixins[name] = method
	end
end
for target,_ in pairs(lib.mixinTargets) do
	lib:Embed(target)
end
local l=AceLocale
if not l then
	L=setmetatable({},{
		__index=function(t,k) return k end
	})
	return
end
-- To avoid clash between versions, localization is versioned on major and minor
-- Lua strings are immutable so having more copies of the same string does not waist a noticeable slice of memory
local me=MAJOR_VERSION .. MINOR_VERSION
--@do-not-package@
-- Actual translations for test purpose
-- This part will NOT be packaged at all
do
	local L=l:NewLocale(me,"enUS",true,true)
	L["Configuration"] = "Configuration"
	L["Description"] = "Description"
	L["Libraries"] = "Libraries"
	L["Purge1"] = "Delete unused profiles"
	L["Purge2"] = "Deletes all profiles that are not used by a character"
	L["Purge_Desc"] = "You can delete all unused profiles with just one click"
	L["Release Notes"] = "Release Notes"
	L["Toggles"] = "Toggles"
	L["UseDefault1"] = "Switch all characters to \"%s\" profile"
	L["UseDefault2"] = "Uses the \"%s\" profiles for all your toons"
	L["UseDefault_Desc"] = "You can force all your characters to use the \"%s\" profile in order to manage a single configuration"
	L=l:NewLocale(me,"ptBR")
	if (L) then
	L["Configuration"] = "configura\195\167\195\163o"
	L["Description"] = "Descri\195\167\195\163o"
	L["Libraries"] = "bibliotecas"
	L["Release Notes"] = "Notas de Lan\195\167amento"
	L["Toggles"] = "Alterna"
	end
	L=l:NewLocale(me,"frFR")
	if (L) then
	L["Configuration"] = "configuration"
	L["Description"] = "description"
	L["Libraries"] = "biblioth\195\168ques"
	L["Release Notes"] = "notes de version"
	L["Toggles"] = "Bascule"
	end
	L=l:NewLocale(me,"deDE")
	if (L) then
	L["Configuration"] = "Konfiguration"
	L["Description"] = "Beschreibung"
	L["Libraries"] = "Bibliotheken"
	L["Release Notes"] = "Release Notes"
	L["Toggles"] = "Schaltet"
	end
	L=l:NewLocale(me,"koKR")
	if (L) then
	L["Configuration"] = "\234\181\172\236\132\177"
	L["Description"] = "\236\132\164\235\170\133"
	L["Libraries"] = "\235\157\188\236\157\180\235\184\140\235\159\172\235\166\172"
	L["Release Notes"] = "\235\166\180\235\166\172\236\138\164 \235\133\184\237\138\184"
	L["Toggles"] = "\236\160\132\237\153\152"
	end
	L=l:NewLocale(me,"esMX")
	if (L) then
	L["Configuration"] = "Configuraci\195\179n"
	L["Description"] = "Descripci\195\179n"
	L["Libraries"] = "Bibliotecas"
	L["Release Notes"] = "Notas de la versi\195\179n"
	L["Toggles"] = "Alterna"
	end
	L=l:NewLocale(me,"ruRU")
	if (L) then
	L["Configuration"] = "\208\154\208\190\208\189\209\132\208\184\208\179\209\131\209\128\208\176\209\134\208\184\209\143"
	L["Description"] = "\208\158\208\191\208\184\209\129\208\176\208\189\208\184\208\181"
	L["Libraries"] = "\208\145\208\184\208\177\208\187\208\184\208\190\209\130\208\181\208\186\208\184"
	L["Release Notes"] = "\208\159\209\128\208\184\208\188\208\181\209\135\208\176\208\189\208\184\209\143 \208\186 \208\178\209\139\208\191\209\131\209\129\208\186\209\131"
	L["Toggles"] = "\208\159\208\181\209\128\208\181\208\186\208\187\209\142\209\135\208\181\208\189\208\184\208\181"
	end
	L=l:NewLocale(me,"zhCN")
	if (L) then
	L["Configuration"] = "\233\133\141\231\189\174"
	L["Description"] = "\232\175\180\230\152\142"
	L["Libraries"] = "\229\155\190\228\185\166\233\166\134"
	L["Release Notes"] = "\229\143\145\232\161\140\232\175\180\230\152\142"
	L["Toggles"] = "\229\136\135\230\141\162"
	end
	L=l:NewLocale(me,"esES")
	if (L) then
	L["Configuration"] = "Configuraci\195\179n"
	L["Description"] = "Descripci\195\179n"
	L["Libraries"] = "Bibliotecas"
	L["Release Notes"] = "Notas de la versi\195\179n"
	L["Toggles"] = "Alterna"
	end
	L=l:NewLocale(me,"zhTW")
	if (L) then
	L["Configuration"] = "\233\133\141\231\189\174"
	L["Description"] = "\232\175\180\230\152\142"
	L["Libraries"] = "\229\155\190\228\185\166\233\166\134"
	L["Release Notes"] = "\229\143\145\232\161\140\232\175\180\230\152\142"
	L["Toggles"] = "\229\136\135\230\141\162"
	end
	L=l:NewLocale(me,"itIT")
	if (L) then
	L["Configuration"] = "Configurazione"
	L["Description"] = "Descrizione"
	L["Libraries"] = "Librerie"
	L["Purge1"] = "Cancella i profili inutilizzati"
	L["Purge2"] = "Cancella tutti i profili che non sono usati da un personaggio"
	L["Purge_Desc"] = "Puoi cancellare tutti i profili inutilizzati con un singolo click"
	L["Release Notes"] = "Note di rilascio"
	L["Toggles"] = "Interruttori"
	L["UseDefault1"] = "Imposta il profilo \"%s\" su tutti i personaggi"
	L["UseDefault2"] = "Usa il profilo '%s\" per tutti i personaggi"
	L["UseDefault_Desc"] = "Puoi far usare a tutti i tuoi personaggi il profilo \"%s\""
	end
end
L=LibStub("AceLocale-3.0"):GetLocale(me,true)
if true then return end
--@end-do-not-package@
do
	local L=l:NewLocale(me,"enUS",true,true)
L["%s |4follower:followers; with %s"] = true
L["(Ignores low bias ones)"] = true
L["Add %1$d levels to %2$s"] = true
L["Adds a list of other useful followers to tooltip"] = true
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = true
L["Allowed Rewards"] = true
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = true
L["Applied when 'maximize result' is enabled. Default is 80%"] = true
L["Applies the best armor set"] = true
L["Applies the best armor upgrade"] = true
L["Applies the best weapon set"] = true
L["Applies the best weapon upgrade"] = true
L["Archaelogy"] = true
L["Big screen"] = true
L["Blacklisted"] = true
L["Blacklisted missions are ignored in Mission Control"] = true
L["Building Final report"] = true
L["Capped %1$s. Spend at least %2$d of them"] = true
L["Complete all missions without confirmation"] = true
L["Consider again"] = true
L["Disable if you dont want the full Garrison Commander Header."] = true
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = true
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = true
L["Do not show follower icon on plots"] = true
L["Duration Time"] = true
L["Enhance tooltip"] = true
L["Environment Preference"] = true
L["Epic followers are NOT sent alone on xp only missions"] = true
L["Expiration Time"] = true
L["Follower"] = true
L["Follower equipment set or upgrade"] = true
L["Follower experience"] = true
L["Follower set minimum upgrade"] = true
L["Follower Training"] = true
L["Followers status "] = true
L["Garrison Appearance"] = true
L["Garrison Comander Quick Mission Completion"] = true
L["Garrison Commander Mission Control"] = true
L["Global approx. xp reward"] = true
L["Global success chance"] = true
L["Gold incremented!"] = true
L["Hide followers"] = true
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = true
L["IF checked, shows armors on the left and weapons on the right "] = true
L["If you continue, you will lose them"] = true
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = true
L["Ignore \"maxed\""] = true
L["Ignore epic for xp missions."] = true
L["Ignore for all missions"] = true
L["Ignore for this mission"] = true
L["Ignore rare missions"] = true
L["Increased Rewards"] = true
L["Item minimum level"] = true
L["Item Tokens"] = true
L["Left Click to see available missions"] = true
L["Legendary Items"] = true
L["Level 100 epic followers are not used for xp only missions."] = true
L["Makes main mission panel movable"] = true
L["Makes shipyard panel movable"] = true
L["Maximize result"] = true
L["Maximum mission duration."] = true
L["Minimum mission duration."] = true
L["Minimum requested level for equipment rewards"] = true
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = true
L["Minimun chance"] = true
L["Minimun chance success under which ignore missions"] = true
L["Minum needed chance"] = true
L["Minumum needed chance"] = true
L["Mission Control"] = true
L["Mission Duration"] = true
L["Mission shown"] = true
L["Mission shown for follower"] = true
L["Mission Success"] = true
L["Mission time reduced!"] = true
L["Mission with lower success chance will be ignored"] = true
L["Missionlist"] = true
L["Must reload interface to apply"] = true
L["No confirmation"] = true
L["No follower gained xp"] = true
L["No mission prefill"] = true
L["Not blacklisted"] = true
L["Nothing to report"] = true
L["Number of followers"] = true
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = true
L["Only meaningful upgrades are shown"] = true
L["Original concept and interface by %s"] = true
L["Original method"] = true
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = true
L["Other"] = true
L["Other rewards"] = true
L["Other settings"] = true
L["Other useful followers"] = true
L["Processing mission %d of %d"] = true
L["Profession"] = true
L["Racial Preference"] = true
L["Rare missions will not be considered"] = true
L["Reagents"] = true
L["Reputation Items"] = true
L["Reward type"] = true
L["Right-Click to blacklist"] = true
L["Right-Click to remove from blacklist"] = true
L["Rush orders"] = true
L["Shipyard Appearance"] = true
L["Show Garrison Commander menu"] = true
L["Show itemlevel"] = true
L["Show upgrades"] = true
L["Show xp"] = true
L["Slayer"] = true
L["Some follower"] = true
L["Sort missions by:"] = true
L["Submit all your mission at once. No question asked."] = true
L["Success Chance"] = true
L["Swap upgrades positions"] = true
L["Switch between Garrison Commander and Master Plan interface for missions"] = true
L["Threat Counter"] = true
L["To go: %d"] = true
L["Toggles Garrison Commander Menu Header on/off"] = true
L["Toys and Mounts"] = true
L["Unchecking this will allow you to set specific success chance for each reward type"] = true
L["Unlock Panel"] = true
L["Upgrade %1$s to  %2$d itemlevel"] = true
L["Upgrading to |cff00ff00%d|r"] = true
L["Use big screen"] = true
L["Use GC Interface"] = true
L["Uses armor token"] = true
L["Uses weapon token"] = true
L["When checked, show on each follower button missing xp to next level"] = true
L["When checked, show on each follower button weapon and armor level for maxed followers"] = true
L["Xp incremented!"] = true
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = true
L["You can also send mission one by one clicking on each button."] = true
L["You can open the menu clicking on the icon in top right corner"] = true
L["You have ignored followers"] = true
L["You never performed this mission"] = true
L["You performed this mission %d times with a win ratio of"] = true
	L=l:NewLocale(me,"ptBR")
	if (L) then
	end
	L=l:NewLocale(me,"frFR")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4sujet:sujets; avec %s"
L["(Ignores low bias ones)"] = "(Ignorer celles \\224 basse priorit\\233)"
L["Add %1$d levels to %2$s"] = "Ajoute %1$d niveaux \\224 %2$s"
L["Adds a list of other useful followers to tooltip"] = "Ajoute une liste d'autres sujets utiles dans l'infobulle"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "N'affecte que le mode petit \\233cran, masquant la liste par mission de sujet si d\\233coch\\233"
L["Allowed Rewards"] = "R\\233compenses re\\231ues"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "Permet un pourcentage de r\\233ussite inf\\233rieur pour des missions de ressources. Utiliser /gac gui pour le changer. Il est par d\\233faut \\224 80 %."
L["Applied when 'maximize result' is enabled. Default is 80%"] = "Affecter quand \\171 maximiser le r\\233sultat \\187 est actif. Il est par d\\233faut de 80 %"
L["Applies the best armor set"] = "Applique le meilleur ensemble d'armure"
L["Applies the best armor upgrade"] = "Applique la meilleure am\\233lioration d'armure"
L["Applies the best weapon set"] = "Applique le meilleur ensemble d'arme"
L["Applies the best weapon upgrade"] = "Applique la meilleure am\\233lioration d'arme"
L["Archaelogy"] = "Arch\\233ologie"
L["Big screen"] = "Grand \\233cran"
L["Blacklisted"] = "Liste noire"
L["Blacklisted missions are ignored in Mission Control"] = "Les missions en liste noire sont ignor\\233es dans Contr\\244le de mission"
L["Building Final report"] = "Cr\\233ation du rapport final"
L["Capped %1$s. Spend at least %2$d of them"] = "Maxi pour %1$s. En d\\233pensera au moins %2$d"
L["Complete all missions without confirmation"] = "Terminer toutes les missions sans confirmation"
L["Consider again"] = "Reconsid\\233rer"
L["Disable if you dont want the full Garrison Commander Header."] = "\\192 d\\233sactiver si vous ne voulez pas de l'intitul\\233 naval complet"
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "D\\233sactive le remplissage automatique des sujets sur la page de mission, ou maintenir CTRL tout en cliquant sur une mission."
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "D\\233sactiver ceci vous donnera l'interface de version 1.1.8. Rechargera l'interface maintenant."
L["Do not show follower icon on plots"] = "Ne pas afficher l'ic\\244ne des sujets dans leurs emplacements"
L["Duration Time"] = "Dur\\233e"
L["Enhance tooltip"] = "Infobulle am\\233lior\\233e"
L["Environment Preference"] = "Pr\\233f\\233rence d'environnement"
L["Epic followers are NOT sent alone on xp only missions"] = "Les sujets \\233piques ne sont PAS envoy\\233s seuls dans des missions d'XP uniquement"
L["Expiration Time"] = "D\\233lai avant expiration"
L["Follower"] = "Sujet"
L["Follower equipment set or upgrade"] = "\\201quipement du sujet d\\233fini ou am\\233lior\\233"
L["Follower experience"] = "Exp\\233rience du sujet"
L["Follower set minimum upgrade"] = "Am\\233lioration minimale du sujet d\\233finie"
L["Follower Training"] = "Formation de sujet"
L["Followers status "] = "Statuts des sujets"
L["Garrison Appearance"] = "Arriv\\233e de fief"
L["Garrison Comander Quick Mission Completion"] = "Terminer rapidement toutes les missions navales"
L["Garrison Commander Mission Control"] = "Contr\\244le des missions navales"
L["Global approx. xp reward"] = "\\201valuation totale du gain en XP"
L["Global success chance"] = "Chance totale de succ\\232s"
L["Gold incremented!"] = "Or augment\\233 !"
L["Hide followers"] = "Masquer les sujets"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = [=[Si activ\233, cliquer sur une ic\244ne d'am\233lioration fera dispara\238tre l'objet et am\233liorera le sujet
|cFFFF0000AUCUNE CONFIRMATION !|r]=]
L["IF checked, shows armors on the left and weapons on the right "] = "SI coch\\233, affiche les armures \\224 gauche et les armes \\224 droite"
L["If you continue, you will lose them"] = "Si vous continuez, vous le(s) perdrez"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "SI vous avez un centre de tri, vous ne voulez probablement pas avoir \\231a une fois v\\233rifi\\233"
L["Ignore \"maxed\""] = "Ignorer \"maximis\\233\""
L["Ignore epic for xp missions."] = "Ignorer sujet \\233pique pour les missions \\224 XP."
L["Ignore for all missions"] = "Ignorer pour toutes les missions"
L["Ignore for this mission"] = "Ignorer pour cette mission"
L["Ignore rare missions"] = "Ignorer les missions rares"
L["Increased Rewards"] = "Augmentation des r\\233compenses"
L["Item minimum level"] = "Niveau minimum de l'objet"
L["Item Tokens"] = "Objets-jeton"
L["Left Click to see available missions"] = "Cliquer gauche pour voir les missions disponibles"
L["Legendary Items"] = "Objet l\\233gendaire"
L["Level 100 epic followers are not used for xp only missions."] = "Les sujets \\233piques de niveau 100 ne sont pas utilis\\233s pour les missions d'XP uniquement."
L["Makes main mission panel movable"] = "Faire que le panneau principal de missions soit mobile"
L["Makes shipyard panel movable"] = "Faire que le panneau du port naval soit mobile"
L["Maximize result"] = "Maximiser le r\\233sultat"
L["Maximum mission duration."] = "Dur\\233e maximale de mission."
L["Minimum mission duration."] = "Dur\\233e minimale de mission."
L["Minimum requested level for equipment rewards"] = "Niveau requis minimum pour les r\\233compenses d'\\233quipement"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "Am\\233lioration minimale requise pour l'\\233quipement des sujets (les am\\233liorations sont toujours inclus)"
L["Minimun chance"] = "Chance minimale"
L["Minimun chance success under which ignore missions"] = "R\\233ussite minimale en dessous de laquelle les missions seront ignor\\233es"
L["Minum needed chance"] = "Chance minimale n\\233cessaire"
L["Minumum needed chance"] = "Chance minimale n\\233cessaire"
L["Mission Control"] = "Contr\\244le de missions"
L["Mission Duration"] = "Dur\\233e de missions"
L["Mission shown"] = "Affichage de missions"
L["Mission shown for follower"] = "Mission affich\\233e pour les sujets"
L["Mission Success"] = "Succ\\232s de missions"
L["Mission time reduced!"] = "Dur\\233e de mission r\\233duite !"
L["Mission with lower success chance will be ignored"] = "Les missions avec des chances faibles seront ignor\\233es"
L["Missionlist"] = "Liste des missions"
L["Must reload interface to apply"] = "Devra recharger l'interface pour activer"
L["No confirmation"] = "Ne pas confirmer"
L["No follower gained xp"] = "Aucune sujet n'a eu d'XP"
L["No mission prefill"] = "Pas de constitution auto. de missions"
L["Not blacklisted"] = "Ne pas mettre en liste noire"
L["Nothing to report"] = "Rien \\224 signaler"
L["Number of followers"] = "Nombre de sujets"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "Seuls les %1$d premi\\232res missions avec plus de %2$d%% de chances de succ\\232s sont affich\\233es"
L["Only meaningful upgrades are shown"] = "N'afficher que les am\\233liorations utiles"
L["Original concept and interface by %s"] = "Conception et interface originels de %s"
L["Original method"] = "M\\233thode originale"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "Trie original restaure la m\\233thode de trie par d\\233faut, quelle qu'elle f\\251t (si vous avez un autre addon pour trier les missions, il devrait fonctionner \\224 nouveau)"
L["Other"] = "Autre"
L["Other rewards"] = "Autres r\\233compenses"
L["Other settings"] = "Autres param\\232tres"
L["Other useful followers"] = "Autres sujets utiles"
L["Processing mission %d of %d"] = "Traitement de la mission %d sur %d"
L["Profession"] = "M\\233tier"
L["Racial Preference"] = "Pr\\233f\\233rence de race"
L["Rare missions will not be considered"] = "Les missions rares ne sont pas examin\\233es"
L["Reagents"] = "R\\233actifs"
L["Reputation Items"] = "Objets de r\\233putations"
L["Reward type"] = "Type de r\\233compense"
L["Right-Click to blacklist"] = "Clic-droit pour mettre en liste noire"
L["Right-Click to remove from blacklist"] = "Clic-droit pour retirer de la liste noire"
L["Rush orders"] = "Commandes urgentes"
L["Shipyard Appearance"] = "Aspect du port naval"
L["Show Garrison Commander menu"] = "Afficher le menu de Garrison Commander"
L["Show itemlevel"] = "Afficher l'ilvl"
L["Show upgrades"] = "Affiche les am\\233liorations"
L["Show xp"] = "Afficher l'XP"
L["Slayer"] = "Pourfendeur"
L["Some follower"] = "Un sujet"
L["Sort missions by:"] = "Trier les missions par :"
L["Submit all your mission at once. No question asked."] = "Soumettre toutes vos missions en une fois. Aucune confirmation demand\\233e."
L["Success Chance"] = "Chance de succ\\232s"
L["Swap upgrades positions"] = "Mettre \\224 jour les positions permut\\233es"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "Permuter l'interface entre Garrison Commander et Master Plan pour les missions"
L["Threat Counter"] = "Niveau de menace"
L["To go: %d"] = "Aller \\224 : %d"
L["Toggles Garrison Commander Menu Header on/off"] = "Activer/d\\233sactiver le menu d'intitul\\233 de Garrison Commander"
L["Toys and Mounts"] = "Jouets et montures"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "D\\233cocher pour d\\233finir les chances de r\\233ussite pour chaque type de r\\233compense"
L["Unlock Panel"] = "D\\233verrouille le panneau"
L["Upgrade %1$s to  %2$d itemlevel"] = "Am\\233lioration du ilvl de %1$s \\224 %2$d"
L["Upgrading to |cff00ff00%d|r"] = "Am\\233lioration \\224 |cff00ff00%d|r"
L["Use big screen"] = "Utilise la gd taille"
L["Use GC Interface"] = "Utiliser l'interface de GC"
L["Uses armor token"] = "Utiliser le jeton d'armure"
L["Uses weapon token"] = "Utiliser le jeton d'arme"
L["When checked, show on each follower button missing xp to next level"] = "Quand coch\\233, affiche l'XP n\\233cessaire, pour le prochain niveau, sur chaque bouton de sujets"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "Quand coch\\233, affiche le niveau d'arme et d'armure sur chaque bouton des sujets maximis\\233s"
L["Xp incremented!"] = "XP augment\\233e !"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "Vous gaspillez |cffff0000%d|cffffd200 point(s) !!!"
L["You can also send mission one by one clicking on each button."] = "Vous pouvez aussi d\\233buter les missions une par une en cliquant sur chaque bouton."
L["You can open the menu clicking on the icon in top right corner"] = "Vous pouvez ouvrir le menu en cliquant sur l'ic\\244ne dans le coin sup\\233rieur droit"
L["You have ignored followers"] = "Vous avez ignor\\233 des sujets"
L["You never performed this mission"] = "Vous n'avez jamais effectu\\233 cette mission"
L["You performed this mission %d times with a win ratio of"] = "Vous avez effectu\\233 cette mission %d fois avec un rapport de"
	end
	L=l:NewLocale(me,"deDE")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4Anh\\228nger:Anh\\228nger; mit %s"
L["(Ignores low bias ones)"] = "(Niedrigstufige werden ignoriert)"
L["Add %1$d levels to %2$s"] = "Erh\\246he die %2$s um %1$d Stufen"
L["Adds a list of other useful followers to tooltip"] = "F\\252ge dem Tooltip eine Liste anderer n\\252tzlicher Anh\\228nger hinzu"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "Nur f\\252r den Kleinfenstermodus; Versteckt die Pro-Anh\\228nger-Missionsliste, wenn hier das H\\228kchen fehlt."
L["Allowed Rewards"] = "Erlaubte Belohnungen"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "Erlaubt eine geringere Erfolgschance f\\252r Ressourcenmissionen. Mit \"/gac gui\" kannst du diesen Prozentwert \\228ndern. Standard ist 80%."
L["Applied when 'maximize result' is enabled. Default is 80%"] = "Nur wirksam, wenn 'Ergebnis maximieren' aktiv ist. Standard ist 80%"
L["Applies the best armor set"] = "Wendet das beste R\\252stungsset an."
L["Applies the best armor upgrade"] = "Wendet die beste R\\252stungsverbesserung an."
L["Applies the best weapon set"] = "Wendet das beste Waffenset an."
L["Applies the best weapon upgrade"] = "Wendet die beste Waffenverbesserung an."
L["Archaelogy"] = "Arch\\228ologie"
L["Big screen"] = "Gro\\223es Fenster"
L["Blacklisted"] = "Ignoriert"
L["Blacklisted missions are ignored in Mission Control"] = "Ignorierte Missionen werden in der Missionssteuerung ignoriert"
L["Building Final report"] = "Erstelle Abschlussbericht"
L["Capped %1$s. Spend at least %2$d of them"] = "Maximalwert von %1$s erreicht. Gib mindestens %2$d davon aus"
L["Complete all missions without confirmation"] = "Beende alle Missionen ohne Best\\228tigung"
L["Consider again"] = "Wieder ber\\252cksichtigen"
L["Disable if you dont want the full Garrison Commander Header."] = "Deaktiviere diese Option, wenn du den Header vom Garrison Commander nicht haben willst."
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "Deaktiviert das automatische Bef\\252llen von Missionen auf der Missionsseite. Du kannst auch STRG+MAUSKLICK dr\\252cken, um einzelne Missionen zu bef\\252llen."
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "Durch Deaktivieren dieser Option erh\\228ltst du das Interface von 1.1.8. Das Interface muss dabei neu geladen werden."
L["Do not show follower icon on plots"] = "Anh\\228ngersymbole auf den Fl\\228chen nicht anzeigen"
L["Duration Time"] = "Zeitdauer"
L["Enhance tooltip"] = "Tooltip verbessern"
L["Environment Preference"] = "Bevorzugte Umgebung"
L["Epic followers are NOT sent alone on xp only missions"] = "Epische Anh\\228nger werden NICHT allein auf EP-Missionen geschickt"
L["Expiration Time"] = "Ablaufzeit"
L["Follower"] = "Anh\\228nger"
L["Follower equipment set or upgrade"] = "Anh\\228ngerausr\\252stungsset oder -verbesserung"
L["Follower experience"] = "Anh\\228ngererfahrung"
L["Follower set minimum upgrade"] = "Minimale Aufwertung f\\252r Anh\\228ngersets"
L["Follower Training"] = "Anh\\228ngerausbildung"
L["Followers status "] = "Anh\\228ngerstatus"
L["Garrison Appearance"] = "Garnisonsdarstellung"
L["Garrison Comander Quick Mission Completion"] = "GC-Schnellmissionsabschluss"
L["Garrison Commander Mission Control"] = "GC-Missionssteuerung"
L["Global approx. xp reward"] = "Globale ungef\\228hre EP-Belohnung"
L["Global success chance"] = "Gesamte Erfolgschance"
L["Gold incremented!"] = "Gold erh\\246ht!"
L["Hide followers"] = "Anh\\228nger verstecken"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = [=[Wenn aktiviert, wird beim Anklicken eines Aufwertungssymbols der Gegenstand verbraucht und der Anh\228nger verbessert
|cFFFF0000OHNE BEST\196TIGUNGSABFRAGE|r]=]
L["IF checked, shows armors on the left and weapons on the right "] = "Wenn markiert, werden R\\252stungen auf der linken Seite und Waffen auf der rechten Seite angezeigt"
L["If you continue, you will lose them"] = "Wenn du weitermachst, wirst du sie verlieren"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "Wenn du ein Wiederverwertungsgeb\\228ude hast, sollte diese Option deaktiviert bleiben"
L["Ignore \"maxed\""] = "\"Maximierte\" ignorieren"
L["Ignore epic for xp missions."] = "Epische Anh. bei Erfahrungsmissionen ignorieren"
L["Ignore for all missions"] = "Bei allen Missionen ignorieren"
L["Ignore for this mission"] = "Bei dieser Mission ignorieren"
L["Ignore rare missions"] = "Seltene Missionen ignorieren"
L["Increased Rewards"] = "Belohnungsbonus"
L["Item minimum level"] = "Minimale Gegenstandsstufe"
L["Item Tokens"] = "Gegenstandsmarken"
L["Left Click to see available missions"] = "Linksklicke hier, um alle verf\\252gbaren Missionen zu sehen"
L["Legendary Items"] = "Legend\\228re Gegenst\\228nde"
L["Level 100 epic followers are not used for xp only missions."] = "Epische Stufe-100-Anh\\228nger werden nicht bei Nur-EP-Missionen benutzt."
L["Makes main mission panel movable"] = "Macht das Hauptmissionsfenster verschiebbar"
L["Makes shipyard panel movable"] = "Macht das Werftfenster verschiebbar"
L["Maximize result"] = "Ergebnis maximieren"
L["Maximum mission duration."] = "Maximale Missionsdauer"
L["Minimum mission duration."] = "Minimale Missionsdauer"
L["Minimum requested level for equipment rewards"] = "Kleinstm\\246gliche Stufe f\\252r Ausr\\252stungsbelohnungen"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "Kleinstm\\246gliche Aufwertung f\\252r Anh\\228ngersets (Verbesserungen sind immer enthalten)"
L["Minimun chance"] = "Minimalchance"
L["Minimun chance success under which ignore missions"] = "Minimale Erfolgschance \\8211 alle Missionen, die darunter liegen, werden ignoriert"
L["Minum needed chance"] = "Kleinstm\\246gliche Chance"
L["Minumum needed chance"] = "Kleinstm\\246gliche Chance"
L["Mission Control"] = "Missionssteuerung"
L["Mission Duration"] = "Missionsdauer"
L["Mission shown"] = "Anzahl gezeigter Missionen"
L["Mission shown for follower"] = "Angezeigte Missionen f\\252r einen Anh\\228nger"
L["Mission Success"] = "Missionserfolg"
L["Mission time reduced!"] = "Missionszeit reduziert!"
L["Mission with lower success chance will be ignored"] = "Missionen mit geringerer Erfolgschance werden ignoriert"
L["Missionlist"] = "Missionsliste"
L["Must reload interface to apply"] = "Das Interface muss neu geladen werden"
L["No confirmation"] = "Ohne Nachfragen"
L["No follower gained xp"] = "Kein Anh\\228nger bekam Erfahrung"
L["No mission prefill"] = "Kein Vorab-Auff\\252llen bei Missionen"
L["Not blacklisted"] = "Nicht ignoriert"
L["Nothing to report"] = "Es gibt nichts zu berichten"
L["Number of followers"] = "Anzahl der Anh\\228nger"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "Nur die ersten %1$d Missionen mit einer Erfolgschance von \\252ber %2$d%% werden angezeigt"
L["Only meaningful upgrades are shown"] = "Nur sinnvolle Aufwertungen werden angezeigt"
L["Original concept and interface by %s"] = "Originales Konzept und Interface von %s"
L["Original method"] = "Originale Methode"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "Originale Sortierung stellt die originale Sortiermethode wieder her, was auch immer sie war (wenn du ein anderes Addon zum Sortieren der Missionen hast, sollte dieses wieder wirksam werden)"
L["Other"] = "Andere"
L["Other rewards"] = "Sonstige Belohnungen"
L["Other settings"] = "Sonstige Einstellungen"
L["Other useful followers"] = "Andere n\\252tzliche Anh\\228nger"
L["Processing mission %d of %d"] = "Bearbeite Mission %d von %d"
L["Profession"] = "Beruf"
L["Racial Preference"] = "Volksvorliebe"
L["Rare missions will not be considered"] = "Seltene Missionen werden ignoriert"
L["Reagents"] = "Reagenzien"
L["Reputation Items"] = "Rufgegenst\\228nde"
L["Reward type"] = "Belohnungstyp"
L["Right-Click to blacklist"] = "Rechtsklicken, um sie auf die Ignorierliste zu setzen"
L["Right-Click to remove from blacklist"] = "Rechtsklicken, um sie aus der Ignorierliste zu entfernen"
L["Rush orders"] = "Eilauftr\\228ge"
L["Shipyard Appearance"] = "Werftdarstellung"
L["Show Garrison Commander menu"] = "Das Men\\252 von Garrison Commander zeigen"
L["Show itemlevel"] = "Gegenstandsstufe zeigen"
L["Show upgrades"] = "Aufwertungen zeigen"
L["Show xp"] = "EP zeigen"
L["Slayer"] = "Schl\\228chter"
L["Some follower"] = "Manche Anh\\228nger"
L["Sort missions by:"] = "Sortiere Missionen nach:"
L["Submit all your mission at once. No question asked."] = "Beginne alle Missionen mit einem Klick. Es werden keine Fragen gestellt."
L["Success Chance"] = "Erfolgschance"
L["Swap upgrades positions"] = "Positionen der Aufwertungen tauschen"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "Schalte bei Missionen zwischen Garrison-Commander- und Master-Plan-Interface um."
L["Threat Counter"] = "Bedrohungskonter"
L["To go: %d"] = "Noch zu machen: %d"
L["Toggles Garrison Commander Menu Header on/off"] = "Schalte Men\\252-Header vom Garrison Commander an/aus"
L["Toys and Mounts"] = "Spielzeuge und Reittiere"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "Entferne hier das H\\228kchen, wenn du f\\252r jeden Belohnungstyp eine spezifische Erfolgschance angeben willst."
L["Unlock Panel"] = "Fenster freigeben"
L["Upgrade %1$s to  %2$d itemlevel"] = "Werte %1$s um %2$d Gegenstandsstufe(n) auf"
L["Upgrading to |cff00ff00%d|r"] = "Verbessere auf |cff00ff00%d|r"
L["Use big screen"] = "Benutze das gro\\223e Fenster"
L["Use GC Interface"] = "GC-Interface benutzen"
L["Uses armor token"] = "Benutzt R\\252stungsverbesserung"
L["Uses weapon token"] = "Benutzt Waffenverbesserung"
L["When checked, show on each follower button missing xp to next level"] = "Wenn aktiviert, wird auf jedem Anh\\228nger-Button die fehlende EP bis zur n\\228chsten Stufe angezeigt"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "Wenn aktiviert, wird auf jedem Anh\\228nger-Button die Waffen- und R\\252stungsstufe bei maximierten Anh\\228ngern angezeigt"
L["Xp incremented!"] = "EP erh\\246ht!"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "Du verschwendest |cffff0000%d|cffffd200 Punkt(e)!!!"
L["You can also send mission one by one clicking on each button."] = "Du kannst eine Mission auch einzeln beginnen, indem du sie jeweils anklickst."
L["You can open the menu clicking on the icon in top right corner"] = "Du kannst das Men\\252 \\246ffnen, indem du auf das Symbol in der oberen rechten Ecke klickst."
L["You have ignored followers"] = "Du hast ignorierte Anh\\228nger"
L["You never performed this mission"] = "Du hast diese Mission noch nie durchgef\\252hrt."
L["You performed this mission %d times with a win ratio of"] = "Du hast diese Mission %d-mal durchgef\\252hrt, mit einem Gewinnverh\\228ltnis von"
	end
	L=l:NewLocale(me,"itIT")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4seguace:seguaci; con %s"
L["(Ignores low bias ones)"] = "(Ignorati i seguaci di livello basso)"
L["Add %1$d levels to %2$s"] = "Aggiunge %1$d livelli a %2$s"
L["Adds a list of other useful followers to tooltip"] = "Aggiunge altri seguaci utili al tooltip"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "Si applica solo alla modalit\\224 dimensioni native, nascode la lista missioni per seguace se inattivo"
L["Allowed Rewards"] = "Ricompense ammesse"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "Accetta una minor percentuale di successo per le missioni che danno risorse. Con /gac gui puoi cambiare la percentuale (deault 80%)"
L["Applied when 'maximize result' is enabled. Default is 80%"] = "Si applica quando 'massimizza risultato' \\232 abilitato. Default 80%"
L["Applies the best armor set"] = "Applica il miglior set di armatura"
L["Applies the best armor upgrade"] = "Applica il miglior incremento di armatura"
L["Applies the best weapon set"] = "Applica il miglior set di armi"
L["Applies the best weapon upgrade"] = "Applica il milgior incremento di armi"
L["Archaelogy"] = "Archeologia"
L["Big screen"] = "Pannello grande"
L["Blacklisted"] = "Blacklistato"
L["Blacklisted missions are ignored in Mission Control"] = "Le missioni blacklistate vengono ignorate in Controllo Missione"
L["Building Final report"] = "Preparo il report finale"
L["Capped %1$s. Spend at least %2$d of them"] = "Limitato a %1$s. Spendine almeno %2$d"
L["Complete all missions without confirmation"] = "Completa tutte le mission senza conferme"
L["Consider again"] = "Prendi in considerazione di nuovo"
L["Disable if you dont want the full Garrison Commander Header."] = "Disabilita se vuoi la testata completa di Garrison Commander"
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "Disabilita la popolazione automatica della pagina di missione. Puoi anche tenere premuto ctrl mentre clicchi il pulsante missione per non popolare quella specifica missione"
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "Disabilitando questo avrete la vecchia interfaccia (1.1.8). Verr\\224 effettuato un reload dell' interfaccia"
L["Do not show follower icon on plots"] = "Nascondi le icone dei seguaci dalle piazzole"
L["Duration Time"] = "Durata"
L["Enhance tooltip"] = "Migliora il tooltip"
L["Environment Preference"] = "Preferenze Ambientali"
L["Epic followers are NOT sent alone on xp only missions"] = "I seguaci epici NON vengono mandati da soli nelle missioni \"solo pe\""
L["Expiration Time"] = "Ora di scadenza"
L["Follower"] = "Seguace"
L["Follower equipment set or upgrade"] = "Milgioramento armi seguace"
L["Follower experience"] = "Esperienza del seguace"
L["Follower set minimum upgrade"] = "Incremento miniimo del seguace"
L["Follower Training"] = "Istruzione seguace"
L["Followers status "] = "Stato del seguace"
L["Garrison Appearance"] = "Aspetto della Garrison"
L["Garrison Comander Quick Mission Completion"] = "Completamento veloce missioni di Garrison Commander"
L["Garrison Commander Mission Control"] = "Controllo missione di Garrison Commander"
L["Global approx. xp reward"] = "Pe globali approssimativi"
L["Global success chance"] = "Chance globale di successo"
L["Gold incremented!"] = "Oro incrementato!"
L["Hide followers"] = "Nascondi seguaci"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = "Se marcato, cliccando un upgrade l'oggetto verr\\224 consumato e il seguace aggiornato |cFFFF0000SENZA CONFERME|r"
L["IF checked, shows armors on the left and weapons on the right "] = "Inverte la posizione di armi e armature"
L["If you continue, you will lose them"] = "Se continui, le perderai"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "Se avete il Salvage Yard probabilmente questo non lo volete attivo"
L["Ignore \"maxed\""] = "Ignora \"maxati\""
L["Ignore epic for xp missions."] = "Ignora gli epici per le missioni solo pe"
L["Ignore for all missions"] = "Ignora per tutte le missioni"
L["Ignore for this mission"] = "Ignore per questa missione"
L["Ignore rare missions"] = "Ignora le missioni rare"
L["Increased Rewards"] = "Ricompensa Migliorata"
L["Item minimum level"] = "Livello minimo oggetto"
L["Item Tokens"] = "Gettone per oggetti"
L["Left Click to see available missions"] = "Clicca col sinistro per vedere le missioni disponibili"
L["Legendary Items"] = "Oggetti Leggendari"
L["Level 100 epic followers are not used for xp only missions."] = "I seguaci di livello 100 e qualit\\224 epica non sono usati per le missioni di soli pe"
L["Makes main mission panel movable"] = "Rende movibile il pannello principale"
L["Makes shipyard panel movable"] = "Rende movibile il pannello dela Baia"
L["Maximize result"] = "Massimizza risultato"
L["Maximum mission duration."] = "Durata massima"
L["Minimum mission duration."] = "Durata minima"
L["Minimum requested level for equipment rewards"] = "Livello minimo richiesto per le ricompense di tipo equipaggiamento"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "Livello minimo richiesto per gli upgrade dei followers (I token di miglioramenteo sono sempre inclusi)"
L["Minimun chance"] = "Chance minima"
L["Minimun chance success under which ignore missions"] = "Chance di successo minima sotto cui ignorare le missioni"
L["Minum needed chance"] = "Percentuale minima di successo"
L["Minumum needed chance"] = "Chance minima richiesta"
L["Mission Control"] = "Controllo Missione"
L["Mission Duration"] = "Durata della Missione"
L["Mission shown"] = "Missione mostrata"
L["Mission shown for follower"] = "Numero di missioni mostrato per seguace"
L["Mission Success"] = "Missione Completata"
L["Mission time reduced!"] = "Durata ridotta!"
L["Mission with lower success chance will be ignored"] = "Missioni con percentuale di successo inferiore verranno ignorate"
L["Missionlist"] = "Lista Missioni"
L["Must reload interface to apply"] = "E' necessario ricaricare l'interfaccia per applicarlo"
L["No confirmation"] = "Nessuna conferma"
L["No follower gained xp"] = "Nessun seguage ha ottenuto punti esperienza"
L["No mission prefill"] = "Non assegnare alle missioni"
L["Not blacklisted"] = "Non blacklistata"
L["Nothing to report"] = "Niente da riportare"
L["Number of followers"] = "Numero di seguaci"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "Vengono mostrare solo le prime %1$d missions con una speranza di successo supseriore al %2$d%%"
L["Only meaningful upgrades are shown"] = "Vengono mostrati solo gli upgrade che hanno senso per il seguace corrente"
L["Original concept and interface by %s"] = "Concetto originale e interfaccia di %s"
L["Original method"] = "Ordinamento originale"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "Ripristina il metodo di ordinamento originale, Se avete un altro addon che oridna le missioni, sara\\224 questo addon a agestirlo."
L["Other"] = "Altro"
L["Other rewards"] = "Atre ricompense"
L["Other settings"] = "Altre impostazioni"
L["Other useful followers"] = "Altri seguagi che possono aiutare"
L["Processing mission %d of %d"] = "Elaboro la missione %d di %d"
L["Profession"] = "Professione"
L["Racial Preference"] = "Intesa Razziale"
L["Rare missions will not be considered"] = "Le missioni rare non vengono considerate"
L["Reagents"] = "Reagenti"
L["Reputation Items"] = "Item di reputazione"
L["Reward type"] = "Tipo ricompensa"
L["Right-Click to blacklist"] = "Clicca col destro per blacklistare"
L["Right-Click to remove from blacklist"] = "Clicca col destro per rimuovere dalla blacklist"
L["Rush orders"] = "Commissione"
L["Shipyard Appearance"] = "Aspetto della Baia"
L["Show Garrison Commander menu"] = "Mostra il menu di Garrison Commander"
L["Show itemlevel"] = "Mostra il livello degli item"
L["Show upgrades"] = "Mostra miglioramenti"
L["Show xp"] = "Mostrape"
L["Slayer"] = "Sterminio"
L["Some follower"] = "Un seguace"
L["Sort missions by:"] = "Ordina le missioni per:"
L["Submit all your mission at once. No question asked."] = "Lancia tutte le missioni con un click. Non chiede conferma"
L["Success Chance"] = "Probabilit\\224 di successo"
L["Swap upgrades positions"] = "Inverti la posizione degli upgrades"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "Alterna fra l'interfaccia di Garrison Commander e quella di Master Plan"
L["Threat Counter"] = "Contrasto Minaccia"
L["To go: %d"] = "Mancano: %d"
L["Toggles Garrison Commander Menu Header on/off"] = "Attiva/disattiva il menu di Garrison Commander"
L["Toys and Mounts"] = "Giocattoli e Cavalcature"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "Disabilita per impostare una percentuale specifica di successo per ogni ricompensa"
L["Unlock Panel"] = "Sblocca il pannello"
L["Upgrade %1$s to  %2$d itemlevel"] = "Aggiorna %1$s a %2$d itemlevel"
L["Upgrading to |cff00ff00%d|r"] = "Aggiorno a |cff00ff00%d|r"
L["Use big screen"] = "Utilizza il pannello ingrandito"
L["Use GC Interface"] = "Usa l'interfaccia di GC"
L["Uses armor token"] = "Usa il token per l'armatura"
L["Uses weapon token"] = "Usa il token per le armi"
L["When checked, show on each follower button missing xp to next level"] = "Se attivo, su ogni seguace vengono mostrati i pe mancanti al prossimo livello"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "Se attivo, su ogni seguace viene mostrato l'itemlevel di armi e armatura"
L["Xp incremented!"] = "Pe aumentati!"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "Stai sprecando |cffff0000%d|cffffd200 punti!!!"
L["You can also send mission one by one clicking on each button."] = "Puoi anche inviare le missioni una per una cliccando sui pulsanti"
L["You can open the menu clicking on the icon in top right corner"] = "Puoi aprire il menu cliccando l'icona in alto a destra"
L["You have ignored followers"] = "Hai seguaci ignorati"
L["You never performed this mission"] = "Non hai mai fatto questa missione"
L["You performed this mission %d times with a win ratio of"] = "Hai fatto questa missione %d volde, con una percentuale di successo del"
	end
	L=l:NewLocale(me,"koKR")
	if (L) then
	end
	L=l:NewLocale(me,"esMX")
	if (L) then
	end
	L=l:NewLocale(me,"ruRU")
	if (L) then
	end
	L=l:NewLocale(me,"zhCN")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4\\38543\\20174\\65306\\38543\\20174\\21547\\26377 %s"
L["(Ignores low bias ones)"] = "\\65288\\24573\\30053\\20302\\21305\\37197\\30340\\65289"
L["Add %1$d levels to %2$s"] = "\\22686\\21152 %1$d \\31561\\32423\\21040 %2$s"
L["Adds a list of other useful followers to tooltip"] = "\\40736\\26631\\25552\\31034\\20013\\28155\\21152\\20854\\20182\\26377\\29992\\30340\\38543\\20174\\21015\\34920"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "\\21462\\28040\\36873\\20013\\20197\\38544\\34255\\27599\\20010\\36861\\38543\\32773\\30340\\20219\\21153\\21015\\34920\\65292\\20165\\23567\\31383\\21475\\27169\\24335\\26377\\25928"
L["Allowed Rewards"] = "\\21487\\29992\\25910\\30410"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "\\20801\\35768\\36164\\28304\\20219\\21153\\20351\\29992\\36739\\20302\\30340\\25104\\21151\\29575\\12290\\20351\\29992 /gac \\25171\\24320\\30028\\38754\\35843\\25972\\20960\\29575\\65292\\40664\\3574880%"
L["Applied when 'maximize result' is enabled. Default is 80%"] = "\\26368\\22823\\21270\\32467\\26524\\36873\\39033\\21551\\29992\\26102\\29983\\25928\\65292\\40664\\3574880%"
L["Applies the best armor set"] = "\\20351\\29992\\26368\\20339\\25252\\30002\\32452\\21512"
L["Applies the best armor upgrade"] = "\\20351\\29992\\26368\\20339\\25252\\30002\\21319\\32423"
L["Applies the best weapon set"] = "\\20351\\29992\\26368\\20339\\27494\\22120\\32452\\21512"
L["Applies the best weapon upgrade"] = "\\20351\\29992\\26368\\20339\\27494\\22120\\21319\\32423"
L["Archaelogy"] = "\\32771\\21476\\23398"
L["Big screen"] = "\\22823\\31383\\21475"
L["Blacklisted"] = "\\24050\\21152\\20837\\40657\\21517\\21333"
L["Blacklisted missions are ignored in Mission Control"] = "\\22312\\20219\\21153\\38754\\26495\\24050\\21015\\20837\\40657\\21517\\21333\\30340\\20219\\21153\\23558\\34987\\24573\\30053"
L["Building Final report"] = "\\26500\\24314\\26368\\32456\\25253\\21578"
L["Capped %1$s. Spend at least %2$d of them"] = "\\26368\\22810 %1$s\\65292\\20351\\29992\\33267\\23569 %2$d"
L["Complete all missions without confirmation"] = "\\26080\\38656\\30830\\35748\\23436\\25104\\25152\\26377\\20219\\21153"
L["Consider again"] = "\\30830\\35748"
L["Disable if you dont want the full Garrison Commander Header."] = "\\31105\\29992\\23436\\25972\\30340 Garrison Commander \\26631\\39064"
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "\\21462\\28040\\20219\\21153\\39029\\33258\\21160\\20998\\37197\\12290\\20320\\20063\\21487\\20197\\25353\\20303Ctrl\\38190\\28857\\20987\\21462\\28040\\21333\\20010\\20219\\21153\\12290"
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "\\21462\\28040\\23558\\37325\\26032\\36733\\208371.1.8\\29256\\26412\\30028\\38754\\65292\\21462\\28040\\25110\\30830\\35748\\12290\\38656\\35201\\37325\\36733\\30028\\38754\\12290"
L["Do not show follower icon on plots"] = "\\19981\\35201\\22312\\35745\\21010\\26465\\19978\\26174\\31034\\36861\\38543\\32773\\22270\\26631"
L["Duration Time"] = "\\21608\\26399\\26102\\38388"
L["Enhance tooltip"] = "\\24378\\21270\\40736\\26631\\25552\\31034"
L["Environment Preference"] = "\\29615\\22659\\35774\\32622"
L["Epic followers are NOT sent alone on xp only missions"] = "\\32043\\33394\\36861\\38543\\32773\\19981\\20250\\21333\\29420\\20998\\37197\\21040\\21482\\26377\\32463\\39564\\30340\\20219\\21153\\19978"
L["Expiration Time"] = "\\36807\\26399\\26102\\38388"
L["Follower"] = "\\38543\\20174"
L["Follower equipment set or upgrade"] = "\\38543\\20174\\35013\\22791\\35774\\32622\\25110\\21319\\32423"
L["Follower experience"] = "\\38543\\20174\\32463\\39564"
L["Follower set minimum upgrade"] = "\\38543\\20174\\35774\\32622\\26368\\23567\\21319\\32423"
L["Follower Training"] = "\\38543\\20174\\35757\\32451"
L["Followers status "] = "\\36861\\38543\\32773\\29366\\24577"
L["Garrison Appearance"] = "\\20853\\33829\\30028\\38754"
L["Garrison Comander Quick Mission Completion"] = "GC \\24555\\36895\\20219\\21153\\23436\\25104"
L["Garrison Commander Mission Control"] = "GC \\20219\\21153\\31649\\29702"
L["Global approx. xp reward"] = "\\20840\\23616\\22823\\32422\\32463\\39564\\22870\\21169"
L["Global success chance"] = "\\20840\\23616\\25104\\21151\\29575"
L["Gold incremented!"] = "\\37329\\24065\\22686\\21152\\65281"
L["Hide followers"] = "\\38544\\34255\\36861\\38543\\32773"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = [=[\22914\26524\36873\20013\65292\28857\20987\21319\32423\22270\26631\21017\20351\29992\29289\21697\21319\32423\36861\38543\32773
|cFFFF0000\26080\38656\30830\35748|r]=]
L["IF checked, shows armors on the left and weapons on the right "] = "\\36873\\20013\\26102\\65292\\24038\\20391\\26174\\31034\\25252\\30002\\65292\\21491\\20391\\26174\\31034\\27494\\22120"
L["If you continue, you will lose them"] = "\\22914\\26524\\36873\\25321\\32487\\32493\\65292\\20320\\21487\\33021\\20250\\22833\\21435\\20182\\20204"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "\\22914\\26524\\20320\\26377\\25171\\25438\\22120\\65292\\20320\\21487\\33021\\19981\\24895\\24847\\36873\\20013\\36825\\20010"
L["Ignore \"maxed\""] = "\\24573\\30053\\8220\\28385\\32423\\30340\\8221"
L["Ignore epic for xp missions."] = "\\32463\\39564\\20219\\21153\\24573\\30053\\21490\\35799\\38543\\20174"
L["Ignore for all missions"] = "\\24573\\30053\\25152\\26377\\20219\\21153"
L["Ignore for this mission"] = "\\24573\\30053\\36825\\20010\\20219\\21153"
L["Ignore rare missions"] = "\\24573\\30053\\31232\\26377\\20219\\21153"
L["Increased Rewards"] = "\\24050\\22686\\21152\\25910\\30410"
L["Item minimum level"] = "\\29289\\21697\\26368\\20302\\31561\\32423"
L["Item Tokens"] = "\\29289\\21697\\20195\\24065"
L["Left Click to see available missions"] = "\\28857\\20987\\26174\\31034\\21487\\29992\\20219\\21153"
L["Legendary Items"] = "\\20256\\22855\\29289\\21697"
L["Level 100 epic followers are not used for xp only missions."] = "100\\32423\\30340\\32043\\33394\\36861\\38543\\32773\\19981\\20250\\29992\\20110\\21482\\26377\\32463\\39564\\30340\\20219\\21153"
L["Makes main mission panel movable"] = "\\20351\\20219\\21153\\20027\\31383\\20307\\21487\\20197\\31227\\21160"
L["Makes shipyard panel movable"] = "\\20351\\33328\\33337\\38754\\26495\\21487\\20197\\31227\\21160"
L["Maximize result"] = "\\26368\\22823\\21270\\25910\\30410"
L["Maximum mission duration."] = "\\26368\\22823\\20219\\21153\\21608\\26399"
L["Minimum mission duration."] = "\\26368\\23567\\20219\\21153\\21608\\26399"
L["Minimum requested level for equipment rewards"] = "\\35774\\22791\\22870\\21169\\25152\\38656\\26368\\23567\\31561\\32423"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "\\38543\\20174\\32452\\21512\\65288\\24050\\32771\\34385\\32452\\21512\\24378\\21270\\65289\\25152\\38656\\26368\\23567\\21319\\32423"
L["Minimun chance"] = "\\26368\\23567\\20960\\29575"
L["Minimun chance success under which ignore missions"] = "\\24573\\30053\\20219\\21153\\30340\\26368\\20302\\25104\\21151\\29575"
L["Minum needed chance"] = "\\26368\\23567\\24517\\39035\\20960\\29575"
L["Minumum needed chance"] = "\\26368\\23567\\25152\\38656\\20960\\29575"
L["Mission Control"] = "\\20219\\21153\\38754\\26495"
L["Mission Duration"] = "\\20219\\21153\\21608\\26399"
L["Mission shown"] = "\\20219\\21153\\23637\\31034"
L["Mission shown for follower"] = "\\20219\\21153\\26174\\31034\\36861\\38543\\32773"
L["Mission Success"] = "\\20219\\21153\\25104\\21151"
L["Mission time reduced!"] = "\\20219\\21153\\26102\\38388\\20943\\23569\\65281"
L["Mission with lower success chance will be ignored"] = "\\20302\\25104\\21151\\29575\\20219\\21153\\23558\\34987\\24573\\30053"
L["Missionlist"] = "\\20219\\21153\\21015\\34920"
L["Must reload interface to apply"] = "\\38656\\35201\\37325\\36733\\30028\\38754\\20197\\29983\\25928"
L["No confirmation"] = "\\27809\\26377\\30830\\35748"
L["No follower gained xp"] = "\\27809\\26377\\38543\\20174\\33719\\24471\\32463\\39564"
L["No mission prefill"] = "\\27809\\26377\\39044\\20998\\37197\\20219\\21153"
L["Not blacklisted"] = "\\27809\\26377\\34987\\21015\\20837\\40657\\21517\\21333"
L["Nothing to report"] = "\\27809\\26377\\21487\\29992\\25253\\21578"
L["Number of followers"] = "\\36861\\38543\\32773\\25968\\37327"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "\\21482\\26377\\25104\\21151\\29575\\39640\\20110 %2$d%% \\30340\\21069 %1$d \\20010\\20219\\21153\\20250\\26174\\31034"
L["Only meaningful upgrades are shown"] = "\\21482\\26377\\26126\\26174\\30340\\21319\\32423\\20250\\26174\\31034"
L["Original concept and interface by %s"] = "\\21407\\27010\\24565\\21644\\30028\\38754\\20174 %s"
L["Original method"] = "\\21407\\26041\\27861"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "\\24378\\21046\\24674\\22797\\21407\\25490\\24207\\65288\\22914\\26524\\20320\\26377\\21478\\19968\\20010\\25554\\20214\\25490\\24207\\20219\\21153\\65292\\23427\\24212\\35813\\20250\\20877\\27425\\21551\\21160\\65289"
L["Other"] = "\\20854\\20182"
L["Other rewards"] = "\\20854\\20182\\25910\\30410"
L["Other settings"] = "\\20854\\20182\\35774\\32622"
L["Other useful followers"] = "\\20854\\20182\\26377\\29992\\30340\\36861\\38543\\32773"
L["Processing mission %d of %d"] = "\\25191\\34892\\20219\\21153 %d / %d"
L["Profession"] = "\\19987\\19994\\21305\\37197"
L["Racial Preference"] = "\\31181\\26063\\21305\\37197"
L["Rare missions will not be considered"] = "\\31232\\26377\\20219\\21153\\23558\\19981\\34987\\32771\\34385"
L["Reagents"] = "\\35797\\21058"
L["Reputation Items"] = "\\22768\\26395\\29289\\21697"
L["Reward type"] = "\\25910\\30410\\31867\\22411"
L["Right-Click to blacklist"] = "\\21491\\20987\\21152\\20837\\40657\\21517\\21333"
L["Right-Click to remove from blacklist"] = "\\21491\\20987\\20174\\40657\\21517\\21333\\31227\\38500"
L["Rush orders"] = "\\21047\\35746\\21333"
L["Shipyard Appearance"] = "\\36896\\33337\\21378\\22806\\35266"
L["Show Garrison Commander menu"] = "\\26174\\31034 GC \\33756\\21333"
L["Show itemlevel"] = "\\26174\\31034\\29289\\21697\\31561\\32423"
L["Show upgrades"] = "\\26174\\31034\\21319\\32423"
L["Show xp"] = "\\26174\\31034\\32463\\39564"
L["Slayer"] = "\\29983\\29289\\21305\\37197"
L["Some follower"] = "\\19968\\20123\\38543\\20174"
L["Sort missions by:"] = "\\25490\\24207\\20381\\25454\\65306"
L["Submit all your mission at once. No question asked."] = "\\25552\\20132\\25152\\26377\\20219\\21153\\12290\\26080\\38656\\30830\\35748\\12290"
L["Success Chance"] = "\\25104\\21151\\29575"
L["Swap upgrades positions"] = "\\20132\\25442\\21319\\32423\\20301\\32622"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "\\20026\\20219\\21153\\20999\\25442 Garrison Commander \\21644 Master Plan \\30028\\38754"
L["Threat Counter"] = "\\25216\\33021\\21305\\37197"
L["To go: %d"] = "\\36716\\21040\\65306%d"
L["Toggles Garrison Commander Menu Header on/off"] = "\\20999\\25442 GC \\33756\\21333\\26631\\39064\\24320\\20851"
L["Toys and Mounts"] = "\\29609\\20855\\21644\\22352\\39569"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "\\21462\\28040\\36825\\20010\\36873\\39033\\65292\\20320\\21487\\20197\\33258\\34892\\35774\\32622\\21508\\39033\\25910\\30410\\30340\\25104\\21151\\29575"
L["Unlock Panel"] = "\\35299\\38145\\38754\\26495"
L["Upgrade %1$s to  %2$d itemlevel"] = "\\21319\\32423 %1$s \\21040 %2$d \\29289\\21697\\31561\\32423"
L["Upgrading to |cff00ff00%d|r"] = "\\27491\\22312\\21319\\32423\\33267 |cff00ff00%d|r"
L["Use big screen"] = "\\20351\\29992\\22823\\23631"
L["Use GC Interface"] = "\\20351\\29992GC\\30028\\38754"
L["Uses armor token"] = "\\20351\\29992\\25252\\30002\\20195\\24065"
L["Uses weapon token"] = "\\20351\\29992\\27494\\22120\\20195\\24065"
L["When checked, show on each follower button missing xp to next level"] = "\\36873\\20013\\21518\\65292\\22312\\27599\\20010\\36861\\38543\\32773\\25353\\38062\\19978\\26174\\31034\\21319\\33267\\19979\\19968\\32423\\25152\\38656\\32463\\39564"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "\\36873\\20013\\21518\\65292\\22312\\27599\\20010\\28385\\32423\\36861\\38543\\32773\\25353\\38062\\19978\\26174\\31034\\27494\\22120\\21644\\25252\\30002\\31561\\32423"
L["Xp incremented!"] = "\\32463\\39564\\22686\\21152\\65281"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "\\20320\\28010\\36153\\20102 |cffff0000%d|cffffd200 \\28857\\65281"
L["You can also send mission one by one clicking on each button."] = "\\20320\\20063\\21487\\20197\\28857\\20987\\25353\\38062\\36880\\20010\\20998\\37197\\20219\\21153\\12290"
L["You can open the menu clicking on the icon in top right corner"] = "\\20320\\21487\\20197\\28857\\20987\\21491\\19978\\35282\\30340\\22270\\26631\\25171\\24320\\33756\\21333"
L["You have ignored followers"] = "\\20320\\26377\\24573\\30053\\30340\\36861\\38543\\32773"
L["You never performed this mission"] = "\\20320\\20174\\26410\\25191\\34892\\36825\\20010\\20219\\21153"
L["You performed this mission %d times with a win ratio of"] = "\\20320\\25191\\34892\\36825\\20010\\20219\\21153 %d \\27425\\65292\\25104\\21151\\29575\\20026"
	end
	L=l:NewLocale(me,"esES")
	if (L) then
	end
	L=l:NewLocale(me,"zhTW")
	if (L) then
L["%s |4follower:followers; with %s"] = "%s |4\\36861\\38568\\32773:\\36861\\38568\\32773; \\26377 %s"
L["(Ignores low bias ones)"] = "(\\24573\\30053\\20302\\31561\\20559\\22909\\30340)"
L["Add %1$d levels to %2$s"] = "\\22686\\21152 %1$d \\31561\\32026\\21040 %2$s"
L["Adds a list of other useful followers to tooltip"] = "\\22312\\24037\\20855\\25552\\31034\\22686\\21152\\20854\\20182\\26377\\29992\\30340\\36861\\38568\\32773\\28165\\21934"
L["Affects only little screen mode, hiding the per follower mission list if not checked"] = "\\21482\\24433\\38911\\23567\\34722\\24149\\27169\\24335\\65292\\22914\\26524\\26410\\21246\\36984\\21063\\38577\\34255\\27599\\20491\\36861\\38568\\32773\\30340\\20219\\21209\\28165\\21934"
L["Allowed Rewards"] = "\\20801\\35377\\30340\\29518\\21237"
L["Allows a lower success percentage for resource missions. Use /gac gui to change percentage. Default is 80%"] = "\\20801\\35377\\20302\\25104\\21151\\29575\\30340\\36039\\28304\\20219\\21209\\12290\\20351\\29992/gac gui\\20358\\25913\\35722\\30334\\20998\\27604\\12290\\38928\\35373\\2885880%"
L["Applied when 'maximize result' is enabled. Default is 80%"] = "\\21482\\22312'\\26368\\22823\\21270\\32080\\26524'\\21855\\29992\\26178\\24433\\38911\\65292\\38928\\35373\\2885880%"
L["Applies the best armor set"] = "\\25033\\29992\\22312\\26368\\20339\\35703\\30002\\19978"
L["Applies the best armor upgrade"] = "\\25033\\29992\\22312\\26368\\20339\\35703\\30002\\21319\\32026\\19978"
L["Applies the best weapon set"] = "\\25033\\29992\\22312\\26368\\20339\\27494\\22120\\19978"
L["Applies the best weapon upgrade"] = "\\25033\\29992\\22312\\26368\\20339\\27494\\22120\\21319\\32026\\19978"
L["Archaelogy"] = "\\32771\\21476\\23416"
L["Big screen"] = "\\22823\\34722\\24149"
L["Blacklisted"] = "\\21015\\20837\\40657\\21517\\21934"
L["Blacklisted missions are ignored in Mission Control"] = "\\40657\\21517\\21934\\20013\\30340\\20219\\21209\\26371\\22312\\20219\\21209\\25511\\21046\\20013\\24573\\30053"
L["Building Final report"] = "\\27491\\22312\\24314\\31435\\32317\\32080\\22577\\21578"
L["Capped %1$s. Spend at least %2$d of them"] = "%1$s\\23553\\38914\\20102\\12290\\33457\\36027\\33267\\23569%2$d\\22312\\20182\\36523\\19978"
L["Complete all missions without confirmation"] = "\\23436\\25104\\25152\\26377\\20219\\21209\\19981\\38920\\30906\\35469"
L["Consider again"] = "\\20877\\27425\\32771\\37327"
L["Disable if you dont want the full Garrison Commander Header."] = "\\22914\\26524\\24744\\19981\\24819\\35201\\23436\\25972\\30340Garrison Commander\\27161\\38988\\21487\\20197\\20572\\29992"
L["Disables automatic population of mission page screen. You can also press control while clicking to disable it for a single mission"] = "\\21462\\28040\\33258\\21205\\20998\\27966\\22312\\20219\\21209\\38913\\31721\\36984\\12290\\24744\\20063\\21487\\20197\\22312\\21934\\19968\\20219\\21209\\19978\\40670\\25802Ctrl\\20358\\21462\\28040\\12290"
L["Disabling this will give you the interface from 1.1.8, given or taken. Need to reload interface"] = "\\21462\\28040\\27492\\26371\\32102\\247441.1.8\\20197\\20358\\30340\\20171\\38754\\65292\\32102\\20104\\25110\\21462\\24471\\12290\\38656\\35201\\37325\\36617UI\\12290"
L["Do not show follower icon on plots"] = "\\19981\\22312\\31574\\30059\\19978\\39023\\31034\\36861\\38568\\32773\\22294\\31034"
L["Duration Time"] = "\\25345\\32396\\26178\\38291"
L["Enhance tooltip"] = "\\22686\\24375\\25552\\31034"
L["Environment Preference"] = "\\29872\\22659\\20559\\22909"
L["Epic followers are NOT sent alone on xp only missions"] = "\\21490\\35433\\36861\\38568\\32773\"\\19981\"\\26371\\21934\\29544\\27966\\30332\\21040\\21482\\26377\\32147\\39511\\20540\\30340\\20219\\21209"
L["Expiration Time"] = "\\36942\\26399\\26178\\38291"
L["Follower"] = "\\36861\\38568\\32773"
L["Follower equipment set or upgrade"] = "\\36861\\38568\\32773\\35037\\20633\\22871\\35037\\25110\\21319\\32026"
L["Follower experience"] = "\\36861\\38568\\32773\\32147\\39511"
L["Follower set minimum upgrade"] = "\\36861\\38568\\32773\\22871\\35037\\26368\\23567\\30340\\21319\\32026"
L["Follower Training"] = "\\36861\\38568\\32773\\35347\\32244"
L["Followers status "] = "\\36861\\38568\\32773\\29376\\24907"
L["Garrison Appearance"] = "\\35201\\22622\\22806\\35264"
L["Garrison Comander Quick Mission Completion"] = "Garrison Comander\\20219\\21209\\24555\\36895\\23436\\25104"
L["Garrison Commander Mission Control"] = "Garrison Commander\\20219\\21209\\25511\\21046"
L["Global approx. xp reward"] = "\\36890\\29992\\22823\\32004\\30340\\32147\\39511\\20540\\29518\\36062"
L["Global success chance"] = "\\20840\\23616\\25104\\21151\\27231\\29575"
L["Gold incremented!"] = "\\40643\\37329\\22686\\21152\\65281"
L["Hide followers"] = "\\38577\\34255\\36861\\38568\\32773"
L["If checked, clicking an upgrade icon will consume the item and upgrade the follower, |cFFFF0000NO QUESTION ASKED|r"] = [=[\22914\26524\21246\36984\65292\25353\19968\19979\21319\32026\22294\31034\23559\20351\29992\35442\29289\21697\21644\21319\32026\36861\38568\32773
|cFFFF0000\19981\38920\30906\35469|r]=]
L["IF checked, shows armors on the left and weapons on the right "] = "\\22914\\26524\\21246\\36984\\65292\\39023\\31034\\35703\\30002\\22312\\24038\\27494\\22120\\22312\\21491"
L["If you continue, you will lose them"] = "\\22914\\26524\\24744\\32380\\32396\\65292\\24744\\26371\\22833\\21435\\23427\\20497"
L["IF you have a Salvage Yard you probably dont want to have this one checked"] = "\\22914\\26524\\24744\\26377\\22238\\25910\\24288\\21487\\33021\\19981\\24819\\35201\\21246\\36984\\27492\\36984\\38917"
L["Ignore \"maxed\""] = "\\24573\\30053\"\\28415\\32026\\30340\""
L["Ignore epic for xp missions."] = "\\24573\\30053\\21490\\35433\\32147\\39511\\20219\\21209\\12290"
L["Ignore for all missions"] = "\\24573\\30053\\25152\\26377\\20219\\21209"
L["Ignore for this mission"] = "\\24573\\30053\\27492\\20219\\21209"
L["Ignore rare missions"] = "\\24573\\30053\\31232\\26377\\20219\\21209"
L["Increased Rewards"] = "\\25552\\39640\\29518\\21237"
L["Item minimum level"] = "\\29289\\21697\\26368\\23567\\31561\\32026"
L["Item Tokens"] = "\\29289\\21697\\36947\\20855"
L["Left Click to see available missions"] = "\\24038\\37749\\40670\\25802\\20197\\27298\\35222\\21487\\29992\\20219\\21209"
L["Legendary Items"] = "\\20659\\22855\\29289\\21697"
L["Level 100 epic followers are not used for xp only missions."] = "\\31561\\32026100\\30340\\21490\\35433\\36861\\38568\\32773\\19981\\26371\\29992\\22312\\21482\\26377\\32147\\39511\\20540\\30340\\20219\\21209\\12290"
L["Makes main mission panel movable"] = "\\35731\\20027\\20219\\21209\\38754\\26495\\21487\\31227\\21205"
L["Makes shipyard panel movable"] = "\\35731\\33337\\22626\\38754\\26495\\21487\\31227\\21205"
L["Maximize result"] = "\\26368\\22823\\21270\\32080\\26524"
L["Maximum mission duration."] = "\\26368\\22823\\20219\\21209\\25345\\32396\\26178\\38291\\12290"
L["Minimum mission duration."] = "\\26368\\23567\\20219\\21209\\25345\\32396\\26178\\38291\\12290"
L["Minimum requested level for equipment rewards"] = "\\35037\\20633\\29518\\21237\\26368\\23567\\38656\\27714\\31561\\32026"
L["Minimum requested upgrade for followers set (Enhancements are always included)"] = "\\36861\\38568\\32773\\22871\\35037\\26368\\23567\\38656\\27714\\21319\\32026(\\22686\\24375\\29289\\21697\\26371\\27704\\36960\\21253\\21547\\22312\\20839)"
L["Minimun chance"] = "\\26368\\23567\\27231\\29575"
L["Minimun chance success under which ignore missions"] = "\\20302\\26044\\22810\\23569\\25104\\21151\\27231\\29575\\30340\\20219\\21209\\35201\\34987\\24573\\30053"
L["Minum needed chance"] = "\\26368\\23567\\38656\\35201\\30340\\27231\\29575"
L["Minumum needed chance"] = "\\26368\\23567\\38656\\27714\\27231\\29575"
L["Mission Control"] = "\\20219\\21209\\25511\\21046"
L["Mission Duration"] = "\\20219\\21209\\25345\\32396\\26178\\38291"
L["Mission shown"] = "\\20219\\21209\\39023\\31034"
L["Mission shown for follower"] = "\\20219\\21209\\19978\\39023\\31034\\36861\\38568\\32773"
L["Mission Success"] = "\\20219\\21209\\25104\\21151"
L["Mission time reduced!"] = "\\20219\\21209\\26178\\38291\\32302\\30701\\65281"
L["Mission with lower success chance will be ignored"] = "\\20302\\26044\\27492\\25104\\21151\\27231\\29575\\30340\\20219\\21209\\23559\\26371\\24573\\30053"
L["Missionlist"] = "\\20219\\21209\\21015\\34920"
L["Must reload interface to apply"] = "\\38656\\35201\\37325\\36617UI\\20197\\29983\\25928"
L["No confirmation"] = "\\19981\\30906\\35469"
L["No follower gained xp"] = "\\27794\\26377\\36861\\38568\\32773\\29554\\24471\\32147\\39511\\20540"
L["No mission prefill"] = "\\27794\\26377\\38928\\32068\\30340\\20219\\21209"
L["Not blacklisted"] = "\\38750\\40657\\21517\\21934"
L["Nothing to report"] = "\\27794\\20160\\40636\\22909\\22577\\21578"
L["Number of followers"] = "\\36861\\38568\\32773\\25976\\37327"
L["Only first %1$d missions with over %2$d%% chance of success are shown"] = "\\21482\\26377\\39640\\26044%2$d%%\\25104\\21151\\27231\\29575\\30340\\21069%1$d\\20219\\21209\\26371\\39023\\31034"
L["Only meaningful upgrades are shown"] = "\\21482\\26377\\26126\\39023\\30340\\21319\\32026\\25165\\26371\\39023\\31034"
L["Original concept and interface by %s"] = "\\21407\\22987\\27010\\24565\\33287\\20171\\38754\\24478%s"
L["Original method"] = "\\21407\\22987\\30340\\26041\\27861"
L["Original sort restores original sorting method, whatever it was (If you have another addon sorting mission, it should kick in again)"] = "\\21407\\22987\\25490\\24207\\23559\\24674\\24489\\21407\\22987\\25490\\24207\\26041\\27861\\65292\\19981\\31649\\23427\\26159\\20160\\40636(\\22914\\26524\\20320\\26377\\21478\\19968\\20491\\25554\\20214\\25490\\24207\\20219\\21209\\65292\\23427\\25033\\35442\\20877\\21855\\21205)"
L["Other"] = "\\20854\\20182"
L["Other rewards"] = "\\20854\\20182\\29518\\21237"
L["Other settings"] = "\\20854\\20182\\35373\\23450"
L["Other useful followers"] = "\\20854\\20182\\26377\\29992\\30340\\36861\\38568\\32773"
L["Processing mission %d of %d"] = "\\34389\\29702\\20013\\20219\\21209%d\\30340%d"
L["Profession"] = "\\32887\\26989"
L["Racial Preference"] = "\\31278\\26063\\20559\\22909"
L["Rare missions will not be considered"] = "\\31232\\26377\\20219\\21209\\19981\\34987\\32771\\24942"
L["Reagents"] = "\\36039\\28304"
L["Reputation Items"] = "\\32882\\26395\\29289\\21697"
L["Reward type"] = "\\29518\\21237\\39006\\22411"
L["Right-Click to blacklist"] = "\\21491\\37749\\40670\\25802\\21152\\20837\\40657\\21517\\21934"
L["Right-Click to remove from blacklist"] = "\\21491\\37749\\40670\\25802\\24478\\40657\\21517\\21934\\31227\\38500"
L["Rush orders"] = "\\36245\\24037\\35330\\21934"
L["Shipyard Appearance"] = "\\33337\\22626\\22806\\35264"
L["Show Garrison Commander menu"] = "\\39023\\31034Garrison Commander\\36984\\21934"
L["Show itemlevel"] = "\\39023\\31034\\29289\\21697\\31561\\32026"
L["Show upgrades"] = "\\39023\\31034\\21319\\32026"
L["Show xp"] = "\\39023\\31034\\32147\\39511\\20540"
L["Slayer"] = "\\27578\\25163"
L["Some follower"] = "\\26576\\20123\\36861\\38568\\32773"
L["Sort missions by:"] = "\\25490\\24207\\20219\\21209\\20381\\25818\\65306"
L["Submit all your mission at once. No question asked."] = "\\19968\\27425\\27966\\36963\\24744\\25152\\26377\\30340\\20219\\21209\\12290\\28961\\38920\\30906\\35469\\12290"
L["Success Chance"] = "\\25104\\21151\\27231\\29575"
L["Swap upgrades positions"] = "\\20132\\25563\\21319\\32026\\20301\\32622"
L["Switch between Garrison Commander and Master Plan interface for missions"] = "\\22312Garrison Commander\\33287Master Plan\\30340\\20219\\21209\\20171\\38754\\20013\\20999\\25563"
L["Threat Counter"] = "\\23041\\33029\\21453\\21046"
L["To go: %d"] = "\\36996\\38656\\35201\\65306%d"
L["Toggles Garrison Commander Menu Header on/off"] = "\\20999\\25563Garrison Commander\\36984\\21934\\27161\\38988 \\38283/\\38364"
L["Toys and Mounts"] = "\\29609\\20855\\33287\\22352\\39438"
L["Unchecking this will allow you to set specific success chance for each reward type"] = "\\21462\\28040\\21246\\36984\\21487\\20197\\20801\\35377\\24744\\28858\\27599\\31278\\29518\\21237\\39006\\22411\\35373\\23450\\29305\\23450\\30340\\25104\\21151\\27231\\29575"
L["Unlock Panel"] = "\\35299\\37782\\38754\\26495"
L["Upgrade %1$s to  %2$d itemlevel"] = "\\21319\\32026%1$s\\21040%2$d\\29289\\21697\\31561\\32026"
L["Upgrading to |cff00ff00%d|r"] = "\\21319\\32026\\21040 |cff00ff00%d|r"
L["Use big screen"] = "\\20351\\29992\\22823\\34722\\24149"
L["Use GC Interface"] = "\\20351\\29992GC\\20171\\38754"
L["Uses armor token"] = "\\20351\\29992\\35703\\30002\\36947\\20855"
L["Uses weapon token"] = "\\20351\\29992\\27494\\22120\\36947\\20855"
L["When checked, show on each follower button missing xp to next level"] = "\\30070\\21246\\36984\\24460\\65292\\39023\\31034\\27599\\20491\\36861\\38568\\32773\\21040\\19979\\19968\\31561\\32026\\25152\\38656\\30340\\32147\\39511\\20540"
L["When checked, show on each follower button weapon and armor level for maxed followers"] = "\\30070\\21246\\36984\\24460\\65292\\39023\\31034\\27599\\20491\\28415\\32026\\36861\\38568\\32773\\27494\\22120\\33287\\35703\\30002\\31561\\32026\\30340\\25353\\37397"
L["Xp incremented!"] = "\\32147\\39511\\20540\\22686\\21152\\65281"
L["You are wasting |cffff0000%d|cffffd200 point(s)!!!"] = "\\24744\\28010\\36027\\20102|cffff0000%d|cffffd200 \\40670\\25976!!!"
L["You can also send mission one by one clicking on each button."] = "\\24744\\20063\\21487\\20197\\36879\\36942\\40670\\25802\\27599\\20491\\25353\\37397\\19968\\20491\\19968\\20491\\27966\\36963\\12290"
L["You can open the menu clicking on the icon in top right corner"] = "\\24744\\21487\\20197\\40670\\25802\\21491\\19978\\35282\\30340\\22294\\31034\\20197\\38283\\21855\\36984\\21934"
L["You have ignored followers"] = "\\24744\\26377\\24573\\30053\\30340\\36861\\38568\\32773"
L["You never performed this mission"] = "\\24744\\26410\\26366\\22519\\34892\\36889\\20491\\20219\\21209"
L["You performed this mission %d times with a win ratio of"] = "\\24744\\22519\\34892\\36942\\27492\\20219\\21209 %d\\27425\\20006\\19988\\25104\\21151\\27231\\29575\\26377"
	end
end
L=LibStub("AceLocale-3.0"):GetLocale(me,true)

